@@ -6,10 +6,13 @@ var group__option__constants =
     [ "HAVE_DSS", "group__option__constants.html#gafdc62dff75931ccafe0a105e62bb1d05", null ],
     [ "HAVE_FILE_LOCKING", "group__option__constants.html#ga55da76844b58de539c47e3fe28bdeb26", null ],
     [ "HAVE_FORK", "group__option__constants.html#ga841db19d8ad8f5d04eaf8980aed008a4", null ],
+    [ "HAVE_GET_NETIF_LIST", "group__option__constants.html#ga39b9cdc4df2f0b13b08ce661b3f31d6b", null ],
+    [ "HAVE_GET_STACK_SIZE", "group__option__constants.html#gae9654317eddd561ad25dbdf76959a60e", null ],
     [ "HAVE_GETPPID", "group__option__constants.html#ga6005570874832f8305631c49cbd54fa3", null ],
     [ "HAVE_IS_EXECUTABLE", "group__option__constants.html#ga0cc55debed9574104abe543102810085", null ],
     [ "HAVE_KILL", "group__option__constants.html#ga905db647155bcf54168df7fc7e6b96b6", null ],
     [ "HAVE_LIBRARY_DEBUGGING", "group__option__constants.html#ga19571712256d5f9817d58c38584510e6", null ],
+    [ "HAVE_MANAGE_STACK", "group__option__constants.html#ga3e3b196e3ae7f8b26e890ce36c120901", null ],
     [ "HAVE_MD2", "group__option__constants.html#ga2e1b34b0ee0e76d35143adeaac8211ba", null ],
     [ "HAVE_MDC2", "group__option__constants.html#ga57cfc96553919fbdae63254ca4600849", null ],
     [ "HAVE_RC5", "group__option__constants.html#ga7c2cfaff4ede608873fa565ed23bc7ab", null ],
@@ -29,6 +32,7 @@ var group__option__constants =
     [ "HAVE_SYMLINK", "group__option__constants.html#gaad0f8a0998b32e445a8708484acbd100", null ],
     [ "HAVE_SYSTEM", "group__option__constants.html#gab0bcd1418b3e06b5a9848d9175e4f744", null ],
     [ "HAVE_TERMIOS", "group__option__constants.html#ga98899bee8f8dda3f4b1feed875118b85", null ],
+    [ "HAVE_THREAD_NAME", "group__option__constants.html#ga5c7b490cc1b6c8749d42067ee4baa7b2", null ],
     [ "HAVE_UNIX_FILEMGT", "group__option__constants.html#gaac007b653cdc3acf169c9cc76ce4a928", null ],
     [ "HAVE_UNIX_USERMGT", "group__option__constants.html#gaef9b69b7df60ff7aa74035d772add3c6", null ]
 ];
\ No newline at end of file
