@@ -500,6 +500,9 @@ var index =
     ] ],
     [ "Keywords", "keywords.html", null ],
     [ "Release Notes", "release_notes.html", [
+      [ "Qore 1.9.1", "release_notes.html#qore_1_9_1", [
+        [ "Bug Fixes in Qore", "release_notes.html#qore_1_9_1_bug_fixes", null ]
+      ] ],
       [ "Qore 1.9.0", "release_notes.html#qore_1_9_0", [
         [ "Bug Fixes in Qore", "release_notes.html#qore_1_9_0_bug_fixes", null ]
       ] ],
