@@ -63,16 +63,16 @@ var NAVTREEINDEX =
 "group__date__and__time__functions.html#ga6a37327d1be86abe99b29c133c3fd0bc",
 "group__error__constants.html",
 "group__exception__type__constants.html#ga1b83beab5fce1ac7290ea7d93e49eeac",
-"group__list__functions.html#ga415240173a996207ae4035180d483302",
-"group__misc__functions.html#ga1e6e24f780713c4d10cb9b98fa45cd35",
-"group__number__formatting__constants.html#ga04d7d50e0d78ac50341f8729c4940947",
-"group__parse__options.html#gaa8259d8e3b4c908f9d09c6987c8c6167",
-"group__string__functions.html#ga33bb08516773ed10def16bb42d6b8159",
-"group__tattr__control__mode__constants.html#ga0c5daa630f8041b3b4147a0c47b9c3b3",
-"group__type__conversion__functions.html#ga62b00f727549f979c1dc83450d2819a2",
-"namespace_qore.html#af04a8a04f9130664f938cf7dc10dbaed",
-"parse_directives.html#require-our",
-"release_notes.html#qore_1_3_0"
+"group__list__functions.html#ga3cff204a3ac62a6fd5690805caba38d0",
+"group__misc__functions.html#ga1d71fa075b5fd841df08e05cfdfc95c6",
+"group__null__and__nothing__constants.html#ga756badc783adcd6a850808b928e21af4",
+"group__parse__options.html#gaa5aaa3b96f4662b3c49bed1d1ab8ec88",
+"group__string__functions.html#ga32070517a9f8a70a32ef48f83a6f128e",
+"group__tattr__control__mode__constants.html#ga043fdb534ff1754f12898d2a5a5246d6",
+"group__type__conversion__functions.html#ga57dc696a2078b28d578b7a034f9ac555",
+"namespace_qore.html#ae895213e0d9f207ab855e4546c791909",
+"parse_directives.html#push-parse-options",
+"release_notes.html#qore_1_2_0_bug_fixes"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
