@@ -1,8 +1,8 @@
 var NAVTREEINDEX10 =
 {
 "group__exception__type__constants.html#ga1b83beab5fce1ac7290ea7d93e49eeac":[4,0,0,956],
-"group__exception__type__constants.html#gac8dc5524f44f9c2ffd6ee5234444122e":[4,0,0,955],
 "group__exception__type__constants.html#gac8dc5524f44f9c2ffd6ee5234444122e":[3,21,0],
+"group__exception__type__constants.html#gac8dc5524f44f9c2ffd6ee5234444122e":[4,0,0,955],
 "group__file__locking__constants.html":[3,10],
 "group__file__locking__constants.html#ga6a9776b4f6e4e751d2ad8011979072c4":[4,0,0,992],
 "group__file__locking__constants.html#ga6a9776b4f6e4e751d2ad8011979072c4":[3,10,1],
@@ -42,59 +42,59 @@ var NAVTREEINDEX10 =
 "group__file__open__constants.html#gaef24f5eb3bd3bd4dd9d4658577376715":[4,0,0,1049],
 "group__file__open__constants.html#gaef24f5eb3bd3bd4dd9d4658577376715":[3,9,6],
 "group__file__seek__constants.html":[3,11],
+"group__file__seek__constants.html#ga1201b62b1ac5ac95f7890d2be610e103":[4,0,0,1193],
 "group__file__seek__constants.html#ga1201b62b1ac5ac95f7890d2be610e103":[3,11,1],
-"group__file__seek__constants.html#ga1201b62b1ac5ac95f7890d2be610e103":[4,0,0,1192],
-"group__file__seek__constants.html#gaf3418d7771017bd7551b14aad79900f3":[4,0,0,1193],
+"group__file__seek__constants.html#gaf3418d7771017bd7551b14aad79900f3":[4,0,0,1194],
 "group__file__seek__constants.html#gaf3418d7771017bd7551b14aad79900f3":[3,11,2],
-"group__file__seek__constants.html#gafb10f9061ee15381748299f4148b5839":[4,0,0,1191],
+"group__file__seek__constants.html#gafb10f9061ee15381748299f4148b5839":[4,0,0,1192],
 "group__file__seek__constants.html#gafb10f9061ee15381748299f4148b5839":[3,11,0],
 "group__file__stat__constants.html":[3,29],
-"group__file__stat__constants.html#ga086cdc31b11ba396d6d8743eb0ab85c2":[4,0,0,1187],
 "group__file__stat__constants.html#ga086cdc31b11ba396d6d8743eb0ab85c2":[3,29,19],
+"group__file__stat__constants.html#ga086cdc31b11ba396d6d8743eb0ab85c2":[4,0,0,1188],
 "group__file__stat__constants.html#ga0e71d3a1ee084309a8718f18d3dc95dc":[3,29,4],
-"group__file__stat__constants.html#ga0e71d3a1ee084309a8718f18d3dc95dc":[4,0,0,1172],
+"group__file__stat__constants.html#ga0e71d3a1ee084309a8718f18d3dc95dc":[4,0,0,1173],
+"group__file__stat__constants.html#ga17069d0ba50fdbb0ab3c0b80d324cc6d":[4,0,0,1176],
 "group__file__stat__constants.html#ga17069d0ba50fdbb0ab3c0b80d324cc6d":[3,29,7],
-"group__file__stat__constants.html#ga17069d0ba50fdbb0ab3c0b80d324cc6d":[4,0,0,1175],
 "group__file__stat__constants.html#ga1b1a9147a783b67902717fe840bc4086":[3,29,6],
-"group__file__stat__constants.html#ga1b1a9147a783b67902717fe840bc4086":[4,0,0,1174],
+"group__file__stat__constants.html#ga1b1a9147a783b67902717fe840bc4086":[4,0,0,1175],
 "group__file__stat__constants.html#ga2bea1d763aafb758ccb9dd2a4a31552a":[3,29,3],
-"group__file__stat__constants.html#ga2bea1d763aafb758ccb9dd2a4a31552a":[4,0,0,1171],
+"group__file__stat__constants.html#ga2bea1d763aafb758ccb9dd2a4a31552a":[4,0,0,1172],
 "group__file__stat__constants.html#ga2c891c3130ae8a0d0d11784b2a42eeb9":[3,29,0],
-"group__file__stat__constants.html#ga2c891c3130ae8a0d0d11784b2a42eeb9":[4,0,0,1168],
+"group__file__stat__constants.html#ga2c891c3130ae8a0d0d11784b2a42eeb9":[4,0,0,1169],
+"group__file__stat__constants.html#ga34ec75099fd680a217e72629eca966d9":[4,0,0,1185],
 "group__file__stat__constants.html#ga34ec75099fd680a217e72629eca966d9":[3,29,16],
-"group__file__stat__constants.html#ga34ec75099fd680a217e72629eca966d9":[4,0,0,1184],
 "group__file__stat__constants.html#ga49f1e458770fef9f6d4687a4cfbaac82":[3,29,8],
-"group__file__stat__constants.html#ga49f1e458770fef9f6d4687a4cfbaac82":[4,0,0,1176],
+"group__file__stat__constants.html#ga49f1e458770fef9f6d4687a4cfbaac82":[4,0,0,1177],
 "group__file__stat__constants.html#ga4dff870bd5c526f49b99688313cb4df1":[3,29,15],
-"group__file__stat__constants.html#ga4dff870bd5c526f49b99688313cb4df1":[4,0,0,1183],
+"group__file__stat__constants.html#ga4dff870bd5c526f49b99688313cb4df1":[4,0,0,1184],
 "group__file__stat__constants.html#ga4e1cd8d467a5a7eb43a6318c5dafd2d2":[3,29,14],
-"group__file__stat__constants.html#ga4e1cd8d467a5a7eb43a6318c5dafd2d2":[4,0,0,1182],
+"group__file__stat__constants.html#ga4e1cd8d467a5a7eb43a6318c5dafd2d2":[4,0,0,1183],
 "group__file__stat__constants.html#ga58f071a14cec07cb61fdbc06d16eab01":[3,29,22],
-"group__file__stat__constants.html#ga58f071a14cec07cb61fdbc06d16eab01":[4,0,0,1190],
+"group__file__stat__constants.html#ga58f071a14cec07cb61fdbc06d16eab01":[4,0,0,1191],
 "group__file__stat__constants.html#ga592399622ad8a25a74510a0daa2e439e":[3,29,17],
-"group__file__stat__constants.html#ga592399622ad8a25a74510a0daa2e439e":[4,0,0,1185],
+"group__file__stat__constants.html#ga592399622ad8a25a74510a0daa2e439e":[4,0,0,1186],
+"group__file__stat__constants.html#ga7a681a17d0e9d9ff3ccbeef067194e7c":[4,0,0,1180],
 "group__file__stat__constants.html#ga7a681a17d0e9d9ff3ccbeef067194e7c":[3,29,11],
-"group__file__stat__constants.html#ga7a681a17d0e9d9ff3ccbeef067194e7c":[4,0,0,1179],
-"group__file__stat__constants.html#ga7ed514c724be3988906c816c5374659f":[4,0,0,1178],
 "group__file__stat__constants.html#ga7ed514c724be3988906c816c5374659f":[3,29,10],
+"group__file__stat__constants.html#ga7ed514c724be3988906c816c5374659f":[4,0,0,1179],
 "group__file__stat__constants.html#ga7f44a136184e71b62d91bd776ed40d6f":[3,29,5],
-"group__file__stat__constants.html#ga7f44a136184e71b62d91bd776ed40d6f":[4,0,0,1173],
+"group__file__stat__constants.html#ga7f44a136184e71b62d91bd776ed40d6f":[4,0,0,1174],
 "group__file__stat__constants.html#gab5933856472006ad8d1c5d43e4c1db4f":[3,29,12],
-"group__file__stat__constants.html#gab5933856472006ad8d1c5d43e4c1db4f":[4,0,0,1180],
+"group__file__stat__constants.html#gab5933856472006ad8d1c5d43e4c1db4f":[4,0,0,1181],
 "group__file__stat__constants.html#gab7e858523e9e02b72379879d2a84f9b5":[3,29,2],
-"group__file__stat__constants.html#gab7e858523e9e02b72379879d2a84f9b5":[4,0,0,1170],
+"group__file__stat__constants.html#gab7e858523e9e02b72379879d2a84f9b5":[4,0,0,1171],
 "group__file__stat__constants.html#gac5d5e6b448289323e591945d291e4032":[3,29,18],
-"group__file__stat__constants.html#gac5d5e6b448289323e591945d291e4032":[4,0,0,1186],
+"group__file__stat__constants.html#gac5d5e6b448289323e591945d291e4032":[4,0,0,1187],
 "group__file__stat__constants.html#gad0591ad36e753abc88c0e155b2132058":[3,29,21],
-"group__file__stat__constants.html#gad0591ad36e753abc88c0e155b2132058":[4,0,0,1189],
+"group__file__stat__constants.html#gad0591ad36e753abc88c0e155b2132058":[4,0,0,1190],
 "group__file__stat__constants.html#gad2469f0282852af931e8f7974847c53a":[3,29,20],
-"group__file__stat__constants.html#gad2469f0282852af931e8f7974847c53a":[4,0,0,1188],
-"group__file__stat__constants.html#gad3055b7e1b13a2f1e814ba2c71a5a852":[4,0,0,1181],
+"group__file__stat__constants.html#gad2469f0282852af931e8f7974847c53a":[4,0,0,1189],
 "group__file__stat__constants.html#gad3055b7e1b13a2f1e814ba2c71a5a852":[3,29,13],
+"group__file__stat__constants.html#gad3055b7e1b13a2f1e814ba2c71a5a852":[4,0,0,1182],
 "group__file__stat__constants.html#gad730b6b55d082561d725650f59559ba4":[3,29,9],
-"group__file__stat__constants.html#gad730b6b55d082561d725650f59559ba4":[4,0,0,1177],
+"group__file__stat__constants.html#gad730b6b55d082561d725650f59559ba4":[4,0,0,1178],
 "group__file__stat__constants.html#gaf248185504f0a91f493b267a9218750f":[3,29,1],
-"group__file__stat__constants.html#gaf248185504f0a91f493b267a9218750f":[4,0,0,1169],
+"group__file__stat__constants.html#gaf248185504f0a91f493b267a9218750f":[4,0,0,1170],
 "group__filesystem__functions.html":[3,48],
 "group__functional__domain__constants.html":[3,14],
 "group__functional__domain__constants.html#ga0b0bb2cc8627c910e5445bf004a8a46b":[4,0,0,939],
@@ -134,8 +134,8 @@ var NAVTREEINDEX10 =
 "group__functional__domain__constants.html#gaf63c9d233d9365eb6d12a48b444485a5":[4,0,0,944],
 "group__functional__domain__constants.html#gaf63c9d233d9365eb6d12a48b444485a5":[3,14,15],
 "group__hmac__functions.html":[3,45,0,0],
-"group__hmac__functions.html#ga227c4f084f2cffee4c466989d68a1fe3":[3,45,0,0,12],
 "group__hmac__functions.html#ga227c4f084f2cffee4c466989d68a1fe3":[4,0,0,315],
+"group__hmac__functions.html#ga227c4f084f2cffee4c466989d68a1fe3":[3,45,0,0,12],
 "group__hmac__functions.html#ga2839943cdcce18a3e5ef63ac5c728eb2":[4,0,0,556],
 "group__hmac__functions.html#ga2839943cdcce18a3e5ef63ac5c728eb2":[3,45,0,0,20],
 "group__hmac__functions.html#ga38c09b0428e8bb11c20fe56ee6353fac":[3,45,0,0,15],
@@ -164,8 +164,8 @@ var NAVTREEINDEX10 =
 "group__hmac__functions.html#gac4dc67bcb217ae04c43a9df9d14d0a85":[3,45,0,0,19],
 "group__hmac__functions.html#gac5ffb694353caa752b069e7b6d018fca":[3,45,0,0,27],
 "group__hmac__functions.html#gac5ffb694353caa752b069e7b6d018fca":[4,0,0,698],
-"group__hmac__functions.html#gaca49d7d4e9a7999b7b11ffa734d98cf3":[4,0,0,252],
 "group__hmac__functions.html#gaca49d7d4e9a7999b7b11ffa734d98cf3":[3,45,0,0,7],
+"group__hmac__functions.html#gaca49d7d4e9a7999b7b11ffa734d98cf3":[4,0,0,252],
 "group__hmac__functions.html#gad159aa97f0f07e827e74b4b9a12b92ca":[4,0,0,226],
 "group__hmac__functions.html#gad159aa97f0f07e827e74b4b9a12b92ca":[3,45,0,0,3],
 "group__hmac__functions.html#gadecee6c469e1b4dade49924bd68c7ae4":[3,45,0,0,21],
@@ -174,8 +174,8 @@ var NAVTREEINDEX10 =
 "group__hmac__functions.html#gae431528555553d236bad69b9ccacb428":[3,45,0,0,10],
 "group__hmac__functions.html#gaeebc2ad2c2cf99a33e42c98344fceb49":[4,0,0,547],
 "group__hmac__functions.html#gaeebc2ad2c2cf99a33e42c98344fceb49":[3,45,0,0,17],
-"group__hmac__functions.html#gaefc09e78e7bccccf7bc3629e4e86c9e2":[3,45,0,0,5],
 "group__hmac__functions.html#gaefc09e78e7bccccf7bc3629e4e86c9e2":[4,0,0,244],
+"group__hmac__functions.html#gaefc09e78e7bccccf7bc3629e4e86c9e2":[3,45,0,0,5],
 "group__hmac__functions.html#gaf76d63347ffb70de4202a771ad767e2d":[3,45,0,0,22],
 "group__hmac__functions.html#gaf76d63347ffb70de4202a771ad767e2d":[4,0,0,684],
 "group__hmac__functions.html#gaf78d06e41607133b0c053a544b2e92b7":[3,45,0,0,23],
@@ -193,29 +193,31 @@ var NAVTREEINDEX10 =
 "group__import__visibility__constants.html#gac013431f5fa7cc6e8d4e3ac4edd090f6":[3,13,2],
 "group__io__constants.html":[3,27],
 "group__io__constants.html#ga0cfa7aea34f3c921036623600e42b21f":[3,27,2],
-"group__io__constants.html#ga0cfa7aea34f3c921036623600e42b21f":[4,0,0,1257],
+"group__io__constants.html#ga0cfa7aea34f3c921036623600e42b21f":[4,0,0,1258],
 "group__io__constants.html#ga44ab38fe66ed7aa87731a2de976017c6":[3,27,4],
-"group__io__constants.html#ga44ab38fe66ed7aa87731a2de976017c6":[4,0,0,1259],
+"group__io__constants.html#ga44ab38fe66ed7aa87731a2de976017c6":[4,0,0,1260],
 "group__io__constants.html#ga697e4968984d273562f14bfed155b4a8":[3,27,0],
-"group__io__constants.html#ga697e4968984d273562f14bfed155b4a8":[4,0,0,1255],
+"group__io__constants.html#ga697e4968984d273562f14bfed155b4a8":[4,0,0,1256],
 "group__io__constants.html#gad35de1bb3d368f94ca75b1a4e165f361":[3,27,5],
-"group__io__constants.html#gad35de1bb3d368f94ca75b1a4e165f361":[4,0,0,1260],
+"group__io__constants.html#gad35de1bb3d368f94ca75b1a4e165f361":[4,0,0,1261],
 "group__io__constants.html#gae2e16a518aa5a69148ad5b218ae91109":[3,27,3],
-"group__io__constants.html#gae2e16a518aa5a69148ad5b218ae91109":[4,0,0,1258],
+"group__io__constants.html#gae2e16a518aa5a69148ad5b218ae91109":[4,0,0,1259],
 "group__io__constants.html#gae762f18fd8b6318f15f8aaf1d18c595e":[3,27,1],
-"group__io__constants.html#gae762f18fd8b6318f15f8aaf1d18c595e":[4,0,0,1256],
+"group__io__constants.html#gae762f18fd8b6318f15f8aaf1d18c595e":[4,0,0,1257],
 "group__library__functions.html":[3,49],
 "group__library__option__constants.html":[3,50],
 "group__library__option__constants.html#ga1ccc5b8f0d7ff2fd2c3b9582c17ecd13":[3,50,1],
 "group__library__option__constants.html#ga1ccc5b8f0d7ff2fd2c3b9582c17ecd13":[4,0,0,1153],
 "group__library__option__constants.html#ga2e0eb3b90ff2ebd04429c29fe5db6fcd":[3,50,3],
 "group__library__option__constants.html#ga2e0eb3b90ff2ebd04429c29fe5db6fcd":[4,0,0,1155],
-"group__library__option__constants.html#ga5515e5a1a7ae8cab55024767f0d0cd94":[3,50,6],
-"group__library__option__constants.html#ga5515e5a1a7ae8cab55024767f0d0cd94":[4,0,0,1158],
+"group__library__option__constants.html#ga5515e5a1a7ae8cab55024767f0d0cd94":[3,50,7],
+"group__library__option__constants.html#ga5515e5a1a7ae8cab55024767f0d0cd94":[4,0,0,1159],
 "group__library__option__constants.html#gaa2695ab22df9c4d4df26e7b08478b7c4":[3,50,0],
 "group__library__option__constants.html#gaa2695ab22df9c4d4df26e7b08478b7c4":[4,0,0,1152],
-"group__library__option__constants.html#gaa772c37cf600c65b5e8dfd446f8ea9cb":[3,50,4],
 "group__library__option__constants.html#gaa772c37cf600c65b5e8dfd446f8ea9cb":[4,0,0,1156],
+"group__library__option__constants.html#gaa772c37cf600c65b5e8dfd446f8ea9cb":[3,50,4],
+"group__library__option__constants.html#gacb98c87cfff3f8bb816945f47d726c80":[3,50,6],
+"group__library__option__constants.html#gacb98c87cfff3f8bb816945f47d726c80":[4,0,0,1158],
 "group__library__option__constants.html#gaea5eee0e93628fbb04c42f667b0a3f6a":[3,50,2],
 "group__library__option__constants.html#gaea5eee0e93628fbb04c42f667b0a3f6a":[4,0,0,1154],
 "group__library__option__constants.html#gaf5a5fddbea9f61a95b70209d3b71459d":[3,50,5],
@@ -247,7 +249,5 @@ var NAVTREEINDEX10 =
 "group__list__functions.html#ga32a3bc8e108a68a446576bd41153867e":[3,51,36],
 "group__list__functions.html#ga3cd34fa7d9cc132e33346c439847f09c":[4,0,0,733],
 "group__list__functions.html#ga3cd34fa7d9cc132e33346c439847f09c":[3,51,44],
-"group__list__functions.html#ga3cff204a3ac62a6fd5690805caba38d0":[4,0,0,543],
-"group__list__functions.html#ga3cff204a3ac62a6fd5690805caba38d0":[3,51,8],
-"group__list__functions.html#ga415240173a996207ae4035180d483302":[4,0,0,728]
+"group__list__functions.html#ga3cff204a3ac62a6fd5690805caba38d0":[4,0,0,543]
 };
