@@ -1,5 +1,7 @@
 var NAVTREEINDEX12 =
 {
+"group__misc__functions.html#ga1d71fa075b5fd841df08e05cfdfc95c6":[4,0,0,125],
+"group__misc__functions.html#ga1d71fa075b5fd841df08e05cfdfc95c6":[3,53,0,4],
 "group__misc__functions.html#ga1e6e24f780713c4d10cb9b98fa45cd35":[4,0,0,598],
 "group__misc__functions.html#ga1e6e24f780713c4d10cb9b98fa45cd35":[3,53,0,100],
 "group__misc__functions.html#ga1f1a63790a7c60a3a61c5d1569fe4e4c":[4,0,0,600],
@@ -10,8 +12,8 @@ var NAVTREEINDEX12 =
 "group__misc__functions.html#ga20e0c1f20a6afc4b02dbd9862996d57a":[3,53,0,109],
 "group__misc__functions.html#ga2269ca395fdfe9214039952c4cacf730":[4,0,0,370],
 "group__misc__functions.html#ga2269ca395fdfe9214039952c4cacf730":[3,53,0,51],
-"group__misc__functions.html#ga23f1e7651ff70e32e9ba7c28907b1306":[4,0,0,294],
 "group__misc__functions.html#ga23f1e7651ff70e32e9ba7c28907b1306":[3,53,0,23],
+"group__misc__functions.html#ga23f1e7651ff70e32e9ba7c28907b1306":[4,0,0,294],
 "group__misc__functions.html#ga24aed47f45573187b6644d5ec1a3aeb5":[4,0,0,300],
 "group__misc__functions.html#ga24aed47f45573187b6644d5ec1a3aeb5":[3,53,0,27],
 "group__misc__functions.html#ga24b04239fa5f45bd1c3d430dfab49019":[4,0,0,513],
@@ -40,8 +42,8 @@ var NAVTREEINDEX12 =
 "group__misc__functions.html#ga34248adafed4b00da2a526f8f23017cf":[3,53,0,63],
 "group__misc__functions.html#ga34c9bccc1d1e61d6a8a8988ceb4a8a6c":[4,0,0,587],
 "group__misc__functions.html#ga34c9bccc1d1e61d6a8a8988ceb4a8a6c":[3,53,0,94],
-"group__misc__functions.html#ga35f238f6343017d7e4736cd2c3007752":[3,53,0,33],
 "group__misc__functions.html#ga35f238f6343017d7e4736cd2c3007752":[4,0,0,327],
+"group__misc__functions.html#ga35f238f6343017d7e4736cd2c3007752":[3,53,0,33],
 "group__misc__functions.html#ga366da9b19ed9b6fb4936f5e5a2ff3663":[4,0,0,511],
 "group__misc__functions.html#ga366da9b19ed9b6fb4936f5e5a2ff3663":[3,53,0,78],
 "group__misc__functions.html#ga3a1dcf3c8f3908896ca2aabfcc41010c":[4,0,0,260],
@@ -84,10 +86,10 @@ var NAVTREEINDEX12 =
 "group__misc__functions.html#ga64ee3ae01383697ae0174fd0cf6cbc5e":[3,53,0,103],
 "group__misc__functions.html#ga69cdaa7f57458a60221fbed9ac2feb38":[4,0,0,383],
 "group__misc__functions.html#ga69cdaa7f57458a60221fbed9ac2feb38":[3,53,0,60],
-"group__misc__functions.html#ga6b1422bc842cbf53cf2bb53ef9322209":[3,53,0,38],
 "group__misc__functions.html#ga6b1422bc842cbf53cf2bb53ef9322209":[4,0,0,348],
-"group__misc__functions.html#ga6b730c0585f1fe62929d6877c32ee0c7":[3,53,0,28],
+"group__misc__functions.html#ga6b1422bc842cbf53cf2bb53ef9322209":[3,53,0,38],
 "group__misc__functions.html#ga6b730c0585f1fe62929d6877c32ee0c7":[4,0,0,301],
+"group__misc__functions.html#ga6b730c0585f1fe62929d6877c32ee0c7":[3,53,0,28],
 "group__misc__functions.html#ga6c7d460b97c3c862717b052355985ded":[4,0,0,585],
 "group__misc__functions.html#ga6c7d460b97c3c862717b052355985ded":[3,53,0,92],
 "group__misc__functions.html#ga6e0d48075f4f39939f6354aa7060e5b4":[4,0,0,448],
@@ -136,8 +138,8 @@ var NAVTREEINDEX12 =
 "group__misc__functions.html#ga9034376bb44beb761d76156600b537f8":[3,53,0,110],
 "group__misc__functions.html#ga98e1d9690329e8c94f88b833af36ef72":[4,0,0,469],
 "group__misc__functions.html#ga98e1d9690329e8c94f88b833af36ef72":[3,53,0,77],
-"group__misc__functions.html#gaa0c7ff8f74f88213fdcee6fd6082b16d":[4,0,0,349],
 "group__misc__functions.html#gaa0c7ff8f74f88213fdcee6fd6082b16d":[3,53,0,39],
+"group__misc__functions.html#gaa0c7ff8f74f88213fdcee6fd6082b16d":[4,0,0,349],
 "group__misc__functions.html#gaa3aa518a4c17e2593c2773bc6b71af3c":[4,0,0,262],
 "group__misc__functions.html#gaa3aa518a4c17e2593c2773bc6b71af3c":[3,53,0,21],
 "group__misc__functions.html#gaa9a0d3f277ef8cbdc99fe146dd3db49b":[4,0,0,303],
@@ -166,8 +168,8 @@ var NAVTREEINDEX12 =
 "group__misc__functions.html#gacb04ca5bd37d873b867186c4da295f0c":[3,53,0,89],
 "group__misc__functions.html#gad08ab1d19f1e77fbaa3d1a3d626ee45c":[4,0,0,595],
 "group__misc__functions.html#gad08ab1d19f1e77fbaa3d1a3d626ee45c":[3,53,0,97],
-"group__misc__functions.html#gad0bbcfc5357d459cb538e57e85c1971e":[3,53,0,15],
 "group__misc__functions.html#gad0bbcfc5357d459cb538e57e85c1971e":[4,0,0,253],
+"group__misc__functions.html#gad0bbcfc5357d459cb538e57e85c1971e":[3,53,0,15],
 "group__misc__functions.html#gad19c4c14c864af9759effecbfef6d68a":[4,0,0,364],
 "group__misc__functions.html#gad19c4c14c864af9759effecbfef6d68a":[3,53,0,45],
 "group__misc__functions.html#gad1e87cdb4aded090b1801d952e018a50":[4,0,0,258],
@@ -227,13 +229,13 @@ var NAVTREEINDEX12 =
 "group__network__address__family__constants.html#gac4f81abe9d374562b41117c51950fb80":[4,0,0,823],
 "group__network__address__family__constants.html#gad33bf2a0a393d1100099acfb6ca644e2":[3,33,0],
 "group__network__address__family__constants.html#gad33bf2a0a393d1100099acfb6ca644e2":[4,0,0,819],
-"group__network__address__family__constants.html#gafda5d0bb6a1cac9536eb682ae75c4b5c":[4,0,0,825],
 "group__network__address__family__constants.html#gafda5d0bb6a1cac9536eb682ae75c4b5c":[3,33,6],
+"group__network__address__family__constants.html#gafda5d0bb6a1cac9536eb682ae75c4b5c":[4,0,0,825],
 "group__network__address__information__constants.html":[3,34],
-"group__network__address__information__constants.html#ga41a7aa51148c443dcab4262b6d5eed56":[4,0,0,829],
 "group__network__address__information__constants.html#ga41a7aa51148c443dcab4262b6d5eed56":[3,34,3],
-"group__network__address__information__constants.html#ga4758a93032a616834593a3172740b973":[3,34,0],
+"group__network__address__information__constants.html#ga41a7aa51148c443dcab4262b6d5eed56":[4,0,0,829],
 "group__network__address__information__constants.html#ga4758a93032a616834593a3172740b973":[4,0,0,826],
+"group__network__address__information__constants.html#ga4758a93032a616834593a3172740b973":[3,34,0],
 "group__network__address__information__constants.html#ga4f24f51906ead287cd6e6cac80b344cb":[3,34,2],
 "group__network__address__information__constants.html#ga4f24f51906ead287cd6e6cac80b344cb":[4,0,0,828],
 "group__network__address__information__constants.html#ga6b06ba8ece0c3d06c2eaead5a0b3735b":[3,34,1],
@@ -245,9 +247,7 @@ var NAVTREEINDEX12 =
 "group__network__address__information__constants.html#gaf18e12f435604a899f9f5fa8fee83a8d":[3,34,5],
 "group__network__address__information__constants.html#gaf18e12f435604a899f9f5fa8fee83a8d":[4,0,0,831],
 "group__null__and__nothing__constants.html":[3,20],
-"group__null__and__nothing__constants.html#ga1805d277be60585d3f2a296c885cf334":[3,20,1],
 "group__null__and__nothing__constants.html#ga1805d277be60585d3f2a296c885cf334":[4,0,0,1042],
-"group__null__and__nothing__constants.html#ga756badc783adcd6a850808b928e21af4":[3,20,0],
-"group__null__and__nothing__constants.html#ga756badc783adcd6a850808b928e21af4":[4,0,0,1026],
-"group__number__formatting__constants.html":[3,0]
+"group__null__and__nothing__constants.html#ga1805d277be60585d3f2a296c885cf334":[3,20,1],
+"group__null__and__nothing__constants.html#ga756badc783adcd6a850808b928e21af4":[3,20,0]
 };
