@@ -1,14 +1,16 @@
 var NAVTREEINDEX13 =
 {
-"group__number__formatting__constants.html#ga04d7d50e0d78ac50341f8729c4940947":[3,0,1],
+"group__null__and__nothing__constants.html#ga756badc783adcd6a850808b928e21af4":[4,0,0,1026],
+"group__number__formatting__constants.html":[3,0],
 "group__number__formatting__constants.html#ga04d7d50e0d78ac50341f8729c4940947":[4,0,0,1022],
-"group__number__formatting__constants.html#ga26210c15de6f9439841b31983989b727":[4,0,0,1021],
+"group__number__formatting__constants.html#ga04d7d50e0d78ac50341f8729c4940947":[3,0,1],
 "group__number__formatting__constants.html#ga26210c15de6f9439841b31983989b727":[3,0,0],
+"group__number__formatting__constants.html#ga26210c15de6f9439841b31983989b727":[4,0,0,1021],
 "group__number__formatting__constants.html#ga69cc628e70f6f1c4c9ba4997ac09e5b8":[3,0,2],
 "group__number__formatting__constants.html#ga69cc628e70f6f1c4c9ba4997ac09e5b8":[4,0,0,1023],
 "group__number__string__formatting__constants.html":[3,1],
 "group__number__string__formatting__constants.html#gab4b7a40f77ac14951ab6f04229a7bb6b":[3,1,0],
-"group__number__string__formatting__constants.html#gab4b7a40f77ac14951ab6f04229a7bb6b":[4,0,0,1240],
+"group__number__string__formatting__constants.html#gab4b7a40f77ac14951ab6f04229a7bb6b":[4,0,0,1241],
 "group__object__functions.html":[3,54],
 "group__object__functions.html#ga1aa450b9391a7e36b01caf570d458ab5":[4,0,0,164],
 "group__object__functions.html#ga1aa450b9391a7e36b01caf570d458ab5":[3,54,9],
@@ -41,26 +43,26 @@ var NAVTREEINDEX13 =
 "group__object__functions.html#gaf3059a3551575f93e04f2f58ae0ab4c4":[4,0,0,160],
 "group__object__functions.html#gaf3059a3551575f93e04f2f58ae0ab4c4":[3,54,5],
 "group__old__dbi__functions.html":[3,46],
-"group__old__dbi__functions.html#ga20fdc611dd5a56fce211b3106578840c":[4,0,0,2,13],
 "group__old__dbi__functions.html#ga20fdc611dd5a56fce211b3106578840c":[3,46,10],
+"group__old__dbi__functions.html#ga20fdc611dd5a56fce211b3106578840c":[4,0,0,2,13],
 "group__old__dbi__functions.html#ga2c836575bb7327e5ef81df5dff4799ff":[4,0,0,2,6],
 "group__old__dbi__functions.html#ga2c836575bb7327e5ef81df5dff4799ff":[3,46,3],
-"group__old__dbi__functions.html#ga330acb764484b16529d4f25960c45fa8":[3,46,7],
 "group__old__dbi__functions.html#ga330acb764484b16529d4f25960c45fa8":[4,0,0,2,10],
+"group__old__dbi__functions.html#ga330acb764484b16529d4f25960c45fa8":[3,46,7],
 "group__old__dbi__functions.html#ga40597983f24f3b0edc06149246d1cbe2":[4,0,0,2,5],
 "group__old__dbi__functions.html#ga40597983f24f3b0edc06149246d1cbe2":[3,46,2],
-"group__old__dbi__functions.html#ga6c3dab42570887656fc05f5a22eb370a":[3,46,11],
 "group__old__dbi__functions.html#ga6c3dab42570887656fc05f5a22eb370a":[4,0,0,2,14],
-"group__old__dbi__functions.html#ga7854c258d52bc1aa47faad90ac5b8e6b":[3,46,9],
+"group__old__dbi__functions.html#ga6c3dab42570887656fc05f5a22eb370a":[3,46,11],
 "group__old__dbi__functions.html#ga7854c258d52bc1aa47faad90ac5b8e6b":[4,0,0,2,12],
-"group__old__dbi__functions.html#ga9cbf88f872bbaebcd1d228efef180117":[4,0,0,2,11],
+"group__old__dbi__functions.html#ga7854c258d52bc1aa47faad90ac5b8e6b":[3,46,9],
 "group__old__dbi__functions.html#ga9cbf88f872bbaebcd1d228efef180117":[3,46,8],
+"group__old__dbi__functions.html#ga9cbf88f872bbaebcd1d228efef180117":[4,0,0,2,11],
 "group__old__dbi__functions.html#gab8f5a597374024a8c78e767dbfcafc15":[3,46,13],
 "group__old__dbi__functions.html#gab8f5a597374024a8c78e767dbfcafc15":[4,0,0,2,16],
 "group__old__dbi__functions.html#gaba3a2421c3d2b492c9494f346c13da1c":[3,46,12],
 "group__old__dbi__functions.html#gaba3a2421c3d2b492c9494f346c13da1c":[4,0,0,2,15],
-"group__old__dbi__functions.html#gae91b14606e0b3d0ca9155a911ec06a5c":[4,0,0,2,7],
 "group__old__dbi__functions.html#gae91b14606e0b3d0ca9155a911ec06a5c":[3,46,4],
+"group__old__dbi__functions.html#gae91b14606e0b3d0ca9155a911ec06a5c":[4,0,0,2,7],
 "group__old__dbi__functions.html#gaec342f12d867758d49be57c1bf2a39cf":[4,0,0,2,9],
 "group__old__dbi__functions.html#gaec342f12d867758d49be57c1bf2a39cf":[3,46,6],
 "group__old__dbi__functions.html#gafc8e6e00000f5c1a029f69d43dc66f82":[3,46,5],
@@ -80,40 +82,40 @@ var NAVTREEINDEX13 =
 "group__option__constants.html#ga39b9cdc4df2f0b13b08ce661b3f31d6b":[3,12,6],
 "group__option__constants.html#ga3bc61668e0fc9fd0a3fd172419e94804":[4,0,0,1,1],
 "group__option__constants.html#ga3bc61668e0fc9fd0a3fd172419e94804":[3,12,1],
-"group__option__constants.html#ga3e3b196e3ae7f8b26e890ce36c120901":[3,12,12],
 "group__option__constants.html#ga3e3b196e3ae7f8b26e890ce36c120901":[4,0,0,1,12],
-"group__option__constants.html#ga518fbbbde3df9c996bbba1d207c5ae10":[4,0,0,1,20],
+"group__option__constants.html#ga3e3b196e3ae7f8b26e890ce36c120901":[3,12,12],
 "group__option__constants.html#ga518fbbbde3df9c996bbba1d207c5ae10":[3,12,20],
+"group__option__constants.html#ga518fbbbde3df9c996bbba1d207c5ae10":[4,0,0,1,20],
 "group__option__constants.html#ga52ed83f65af5516d229f0c5c038da4cc":[4,0,0,1,0],
 "group__option__constants.html#ga52ed83f65af5516d229f0c5c038da4cc":[3,12,0],
 "group__option__constants.html#ga55da76844b58de539c47e3fe28bdeb26":[4,0,0,1,4],
 "group__option__constants.html#ga55da76844b58de539c47e3fe28bdeb26":[3,12,4],
-"group__option__constants.html#ga57cfc96553919fbdae63254ca4600849":[4,0,0,1,14],
 "group__option__constants.html#ga57cfc96553919fbdae63254ca4600849":[3,12,14],
+"group__option__constants.html#ga57cfc96553919fbdae63254ca4600849":[4,0,0,1,14],
 "group__option__constants.html#ga5c7b490cc1b6c8749d42067ee4baa7b2":[4,0,0,1,32],
 "group__option__constants.html#ga5c7b490cc1b6c8749d42067ee4baa7b2":[3,12,32],
-"group__option__constants.html#ga5d3b3ad72dbc870686836888c5cb92e0":[3,12,17],
 "group__option__constants.html#ga5d3b3ad72dbc870686836888c5cb92e0":[4,0,0,1,17],
-"group__option__constants.html#ga5fe2ab14ea36c83e7d032a79bd404622":[3,12,19],
+"group__option__constants.html#ga5d3b3ad72dbc870686836888c5cb92e0":[3,12,17],
 "group__option__constants.html#ga5fe2ab14ea36c83e7d032a79bd404622":[4,0,0,1,19],
-"group__option__constants.html#ga6005570874832f8305631c49cbd54fa3":[4,0,0,1,8],
+"group__option__constants.html#ga5fe2ab14ea36c83e7d032a79bd404622":[3,12,19],
 "group__option__constants.html#ga6005570874832f8305631c49cbd54fa3":[3,12,8],
+"group__option__constants.html#ga6005570874832f8305631c49cbd54fa3":[4,0,0,1,8],
 "group__option__constants.html#ga6a89fa455ea07656dc456faca45c103a":[4,0,0,1,27],
 "group__option__constants.html#ga6a89fa455ea07656dc456faca45c103a":[3,12,27],
-"group__option__constants.html#ga7c2cfaff4ede608873fa565ed23bc7ab":[4,0,0,1,15],
 "group__option__constants.html#ga7c2cfaff4ede608873fa565ed23bc7ab":[3,12,15],
+"group__option__constants.html#ga7c2cfaff4ede608873fa565ed23bc7ab":[4,0,0,1,15],
 "group__option__constants.html#ga8315f695323cb4e3a69f51c85f23cce8":[4,0,0,1,2],
 "group__option__constants.html#ga8315f695323cb4e3a69f51c85f23cce8":[3,12,2],
 "group__option__constants.html#ga841db19d8ad8f5d04eaf8980aed008a4":[4,0,0,1,5],
 "group__option__constants.html#ga841db19d8ad8f5d04eaf8980aed008a4":[3,12,5],
-"group__option__constants.html#ga8bbafb0df946db4960ec53f1739352c2":[4,0,0,1,23],
 "group__option__constants.html#ga8bbafb0df946db4960ec53f1739352c2":[3,12,23],
+"group__option__constants.html#ga8bbafb0df946db4960ec53f1739352c2":[4,0,0,1,23],
 "group__option__constants.html#ga905db647155bcf54168df7fc7e6b96b6":[4,0,0,1,10],
 "group__option__constants.html#ga905db647155bcf54168df7fc7e6b96b6":[3,12,10],
-"group__option__constants.html#ga97aca0d9c20308bd2d79f61c284f7772":[4,0,0,1,16],
 "group__option__constants.html#ga97aca0d9c20308bd2d79f61c284f7772":[3,12,16],
-"group__option__constants.html#ga98899bee8f8dda3f4b1feed875118b85":[3,12,31],
+"group__option__constants.html#ga97aca0d9c20308bd2d79f61c284f7772":[4,0,0,1,16],
 "group__option__constants.html#ga98899bee8f8dda3f4b1feed875118b85":[4,0,0,1,31],
+"group__option__constants.html#ga98899bee8f8dda3f4b1feed875118b85":[3,12,31],
 "group__option__constants.html#gaa1b7b8aa5750d7937b05c0f6d68903bc":[3,12,18],
 "group__option__constants.html#gaa1b7b8aa5750d7937b05c0f6d68903bc":[4,0,0,1,18],
 "group__option__constants.html#gaa2928b4710b3dd34f7bf5a9ba52e7548":[3,12,28],
@@ -124,10 +126,10 @@ var NAVTREEINDEX13 =
 "group__option__constants.html#gaad0f8a0998b32e445a8708484acbd100":[4,0,0,1,29],
 "group__option__constants.html#gab0bcd1418b3e06b5a9848d9175e4f744":[3,12,30],
 "group__option__constants.html#gab0bcd1418b3e06b5a9848d9175e4f744":[4,0,0,1,30],
-"group__option__constants.html#gac2b845ff7b7e953d0ab2c7c0e33154fe":[3,12,22],
 "group__option__constants.html#gac2b845ff7b7e953d0ab2c7c0e33154fe":[4,0,0,1,22],
-"group__option__constants.html#gacb292ea5d97ecc2aa01f852b814e8e02":[4,0,0,1,21],
+"group__option__constants.html#gac2b845ff7b7e953d0ab2c7c0e33154fe":[3,12,22],
 "group__option__constants.html#gacb292ea5d97ecc2aa01f852b814e8e02":[3,12,21],
+"group__option__constants.html#gacb292ea5d97ecc2aa01f852b814e8e02":[4,0,0,1,21],
 "group__option__constants.html#gae9654317eddd561ad25dbdf76959a60e":[4,0,0,1,7],
 "group__option__constants.html#gae9654317eddd561ad25dbdf76959a60e":[3,12,7],
 "group__option__constants.html#gaef9b69b7df60ff7aa74035d772add3c6":[4,0,0,1,34],
@@ -175,8 +177,8 @@ var NAVTREEINDEX13 =
 "group__parse__options.html#ga2d794c7a304d97cae92a819b1aa21e15":[3,15,27],
 "group__parse__options.html#ga2fbe2a73849bb0139d8d228df0e49ea6":[4,0,0,1149],
 "group__parse__options.html#ga2fbe2a73849bb0139d8d228df0e49ea6":[3,15,78],
-"group__parse__options.html#ga32ca9503dd181920af97c058d9bd1164":[4,0,0,1097],
 "group__parse__options.html#ga32ca9503dd181920af97c058d9bd1164":[3,15,26],
+"group__parse__options.html#ga32ca9503dd181920af97c058d9bd1164":[4,0,0,1097],
 "group__parse__options.html#ga35ae9499f18cd62403daceae7bc79c6a":[4,0,0,1121],
 "group__parse__options.html#ga35ae9499f18cd62403daceae7bc79c6a":[3,15,50],
 "group__parse__options.html#ga36ecb26e0659608fc8d35bf9c9a3b5b2":[4,0,0,1104],
@@ -227,14 +229,14 @@ var NAVTREEINDEX13 =
 "group__parse__options.html#ga7cd01bb8ba1560c7893cd9655894c550":[3,15,41],
 "group__parse__options.html#ga80bef77e62dead678bbb426794f5f337":[4,0,0,1088],
 "group__parse__options.html#ga80bef77e62dead678bbb426794f5f337":[3,15,17],
-"group__parse__options.html#ga83f83114a31c6c0367370557650f4ae2":[4,0,0,1087],
 "group__parse__options.html#ga83f83114a31c6c0367370557650f4ae2":[3,15,16],
-"group__parse__options.html#ga889aa80f8ab33266c165478b5fe3c279":[4,0,0,1091],
+"group__parse__options.html#ga83f83114a31c6c0367370557650f4ae2":[4,0,0,1087],
 "group__parse__options.html#ga889aa80f8ab33266c165478b5fe3c279":[3,15,20],
+"group__parse__options.html#ga889aa80f8ab33266c165478b5fe3c279":[4,0,0,1091],
 "group__parse__options.html#ga88a927479c495b99209a6397ef67c240":[4,0,0,1141],
 "group__parse__options.html#ga88a927479c495b99209a6397ef67c240":[3,15,70],
-"group__parse__options.html#ga922d0591649ab5fcfa6d6ca3df24a48a":[4,0,0,1099],
 "group__parse__options.html#ga922d0591649ab5fcfa6d6ca3df24a48a":[3,15,28],
+"group__parse__options.html#ga922d0591649ab5fcfa6d6ca3df24a48a":[4,0,0,1099],
 "group__parse__options.html#ga969ab84c1a550482cbc6d24e878172e9":[4,0,0,1101],
 "group__parse__options.html#ga969ab84c1a550482cbc6d24e878172e9":[3,15,30],
 "group__parse__options.html#ga972fcd1745cc3f4efb6cb2a6e53cd832":[4,0,0,1120],
@@ -247,7 +249,5 @@ var NAVTREEINDEX13 =
 "group__parse__options.html#gaa3d360ed4159338ebbeee314914cb912":[3,15,46],
 "group__parse__options.html#gaa567ec1170360b9ca111402c5179109f":[4,0,0,1100],
 "group__parse__options.html#gaa567ec1170360b9ca111402c5179109f":[3,15,29],
-"group__parse__options.html#gaa5aaa3b96f4662b3c49bed1d1ab8ec88":[4,0,0,1125],
-"group__parse__options.html#gaa5aaa3b96f4662b3c49bed1d1ab8ec88":[3,15,54],
-"group__parse__options.html#gaa8259d8e3b4c908f9d09c6987c8c6167":[4,0,0,1151]
+"group__parse__options.html#gaa5aaa3b96f4662b3c49bed1d1ab8ec88":[4,0,0,1125]
 };
