@@ -1,5 +1,7 @@
 var NAVTREEINDEX14 =
 {
+"group__parse__options.html#gaa5aaa3b96f4662b3c49bed1d1ab8ec88":[3,15,54],
+"group__parse__options.html#gaa8259d8e3b4c908f9d09c6987c8c6167":[4,0,0,1151],
 "group__parse__options.html#gaa8259d8e3b4c908f9d09c6987c8c6167":[3,15,80],
 "group__parse__options.html#gaa92bf6eafb76a4ccf1a0d0df45b13363":[4,0,0,1134],
 "group__parse__options.html#gaa92bf6eafb76a4ccf1a0d0df45b13363":[3,15,63],
@@ -7,8 +9,8 @@ var NAVTREEINDEX14 =
 "group__parse__options.html#gaa932d004bc88438547cdfc4e217461e5":[3,15,3],
 "group__parse__options.html#gaa980dd723754782db7b8be9abe77615a":[4,0,0,1077],
 "group__parse__options.html#gaa980dd723754782db7b8be9abe77615a":[3,15,6],
-"group__parse__options.html#gaab2d8faa88f066837e100152187e6368":[4,0,0,1108],
 "group__parse__options.html#gaab2d8faa88f066837e100152187e6368":[3,15,37],
+"group__parse__options.html#gaab2d8faa88f066837e100152187e6368":[4,0,0,1108],
 "group__parse__options.html#gaab3b95c81206d264aa1ef8899e8a511e":[4,0,0,1132],
 "group__parse__options.html#gaab3b95c81206d264aa1ef8899e8a511e":[3,15,61],
 "group__parse__options.html#gaad25cc6a2b8ede564839d12622d90398":[4,0,0,1084],
@@ -25,8 +27,8 @@ var NAVTREEINDEX14 =
 "group__parse__options.html#gac496a9d9bcf9d5c626c8c267c73a83bc":[3,15,32],
 "group__parse__options.html#gac5bb2159e3353d40072d974c057882b4":[4,0,0,1068],
 "group__parse__options.html#gac5bb2159e3353d40072d974c057882b4":[3,15,2],
-"group__parse__options.html#gac68aaa1c322a68a213b5101265aea716":[4,0,0,1083],
 "group__parse__options.html#gac68aaa1c322a68a213b5101265aea716":[3,15,12],
+"group__parse__options.html#gac68aaa1c322a68a213b5101265aea716":[4,0,0,1083],
 "group__parse__options.html#gac7875c0c85a64fa8b0d66fc634734957":[4,0,0,1148],
 "group__parse__options.html#gac7875c0c85a64fa8b0d66fc634734957":[3,15,77],
 "group__parse__options.html#gacb154a5a9c64065609d22c5fb62b0d04":[4,0,0,1070],
@@ -37,8 +39,8 @@ var NAVTREEINDEX14 =
 "group__parse__options.html#gad0d38cd46f08bf4210d4010204269cc9":[3,15,7],
 "group__parse__options.html#gad7a1c95d88d0f59ecc3e9985b904dd4a":[4,0,0,1071],
 "group__parse__options.html#gad7a1c95d88d0f59ecc3e9985b904dd4a":[3,15,5],
-"group__parse__options.html#gad9c582e8e0ece9d44ceeafa778ac12f1":[4,0,0,1081],
 "group__parse__options.html#gad9c582e8e0ece9d44ceeafa778ac12f1":[3,15,10],
+"group__parse__options.html#gad9c582e8e0ece9d44ceeafa778ac12f1":[4,0,0,1081],
 "group__parse__options.html#gade963e1fbbd1f5b2c777df7221512a1b":[4,0,0,1135],
 "group__parse__options.html#gade963e1fbbd1f5b2c777df7221512a1b":[3,15,64],
 "group__parse__options.html#gaea230eb2f3d02cb456ed8838b805960f":[4,0,0,1119],
@@ -50,131 +52,131 @@ var NAVTREEINDEX14 =
 "group__parse__options.html#gaf8ee107760d23b03c6db359c872cc0f9":[4,0,0,1093],
 "group__parse__options.html#gaf8ee107760d23b03c6db359c872cc0f9":[3,15,22],
 "group__parse__url__options.html":[3,53,0,0],
+"group__parse__url__options.html#ga29e55944d8543c0857a418732aa3df37":[4,0,0,1162],
 "group__parse__url__options.html#ga29e55944d8543c0857a418732aa3df37":[3,53,0,0,2],
-"group__parse__url__options.html#ga29e55944d8543c0857a418732aa3df37":[4,0,0,1161],
-"group__parse__url__options.html#ga8c41e16cce13b426c12c9e28f0cb7b29":[4,0,0,1159],
+"group__parse__url__options.html#ga8c41e16cce13b426c12c9e28f0cb7b29":[4,0,0,1160],
 "group__parse__url__options.html#ga8c41e16cce13b426c12c9e28f0cb7b29":[3,53,0,0,0],
 "group__parse__url__options.html#gad653e5829af0534c19a3873905cc74d9":[3,53,0,0,1],
-"group__parse__url__options.html#gad653e5829af0534c19a3873905cc74d9":[4,0,0,1160],
+"group__parse__url__options.html#gad653e5829af0534c19a3873905cc74d9":[4,0,0,1161],
 "group__protocol__constants.html":[3,35],
 "group__protocol__constants.html#ga207783771cbf914f235bb441f69cec71":[3,35,0],
 "group__protocol__constants.html#ga207783771cbf914f235bb441f69cec71":[4,0,0,1006],
-"group__protocol__constants.html#ga60076c9f99409f2691cf66c521572c41":[4,0,0,1007],
 "group__protocol__constants.html#ga60076c9f99409f2691cf66c521572c41":[3,35,1],
+"group__protocol__constants.html#ga60076c9f99409f2691cf66c521572c41":[4,0,0,1007],
 "group__pwd__functions.html":[3,55],
 "group__range__functions.html":[3,28],
-"group__range__functions.html#ga85798861f6ac3dc0adafaa8db337d8e5":[3,28,1],
 "group__range__functions.html#ga85798861f6ac3dc0adafaa8db337d8e5":[4,0,0,815],
-"group__range__functions.html#gad5b4d3ad3f6c36d2e714bc6ed757a507":[4,0,0,814],
+"group__range__functions.html#ga85798861f6ac3dc0adafaa8db337d8e5":[3,28,1],
 "group__range__functions.html#gad5b4d3ad3f6c36d2e714bc6ed757a507":[3,28,0],
+"group__range__functions.html#gad5b4d3ad3f6c36d2e714bc6ed757a507":[4,0,0,814],
 "group__regex__constants.html":[3,57,0],
-"group__regex__constants.html#ga028abcd0871c7c4a47d8f742d80b2e65":[4,0,0,1163],
+"group__regex__constants.html#ga028abcd0871c7c4a47d8f742d80b2e65":[4,0,0,1164],
 "group__regex__constants.html#ga028abcd0871c7c4a47d8f742d80b2e65":[3,57,0,1],
-"group__regex__constants.html#ga21b62f0275713de5c68a338bc9102f11":[4,0,0,1167],
+"group__regex__constants.html#ga21b62f0275713de5c68a338bc9102f11":[4,0,0,1168],
 "group__regex__constants.html#ga21b62f0275713de5c68a338bc9102f11":[3,57,0,5],
-"group__regex__constants.html#ga5b3cb1f574259b53cedb818cb41977cb":[4,0,0,1164],
+"group__regex__constants.html#ga5b3cb1f574259b53cedb818cb41977cb":[4,0,0,1165],
 "group__regex__constants.html#ga5b3cb1f574259b53cedb818cb41977cb":[3,57,0,2],
-"group__regex__constants.html#gaa5ae5ce8410a6a2a4970fc1b21e06382":[4,0,0,1162],
+"group__regex__constants.html#gaa5ae5ce8410a6a2a4970fc1b21e06382":[4,0,0,1163],
 "group__regex__constants.html#gaa5ae5ce8410a6a2a4970fc1b21e06382":[3,57,0,0],
-"group__regex__constants.html#gad67849c1513d0d160548c2c667855ff0":[4,0,0,1166],
+"group__regex__constants.html#gad67849c1513d0d160548c2c667855ff0":[4,0,0,1167],
 "group__regex__constants.html#gad67849c1513d0d160548c2c667855ff0":[3,57,0,4],
-"group__regex__constants.html#gaea655c36090c9f1e6bb24cb8de998a04":[4,0,0,1165],
+"group__regex__constants.html#gaea655c36090c9f1e6bb24cb8de998a04":[4,0,0,1166],
 "group__regex__constants.html#gaea655c36090c9f1e6bb24cb8de998a04":[3,57,0,3],
 "group__signal__constants.html":[3,53,0,3],
 "group__signal__constants.html#ga0607bd6388adf02985d48239b882a0bd":[3,53,0,3,39],
-"group__signal__constants.html#ga0607bd6388adf02985d48239b882a0bd":[4,0,0,1232],
-"group__signal__constants.html#ga08c2521752c47194e089747074dae077":[4,0,0,1239],
+"group__signal__constants.html#ga0607bd6388adf02985d48239b882a0bd":[4,0,0,1233],
 "group__signal__constants.html#ga08c2521752c47194e089747074dae077":[3,53,0,3,46],
+"group__signal__constants.html#ga08c2521752c47194e089747074dae077":[4,0,0,1240],
 "group__signal__constants.html#ga1865894ae3b452b049f6e9a8ff0c80ff":[3,53,0,3,2],
-"group__signal__constants.html#ga1865894ae3b452b049f6e9a8ff0c80ff":[4,0,0,1195],
+"group__signal__constants.html#ga1865894ae3b452b049f6e9a8ff0c80ff":[4,0,0,1196],
 "group__signal__constants.html#ga1a9d023101a217b83525ea6e2f7581cf":[3,53,0,3,11],
-"group__signal__constants.html#ga1a9d023101a217b83525ea6e2f7581cf":[4,0,0,1204],
+"group__signal__constants.html#ga1a9d023101a217b83525ea6e2f7581cf":[4,0,0,1205],
 "group__signal__constants.html#ga212ae2f9d975d89621c51fdb9204b2ab":[3,53,0,3,37],
-"group__signal__constants.html#ga212ae2f9d975d89621c51fdb9204b2ab":[4,0,0,1230],
+"group__signal__constants.html#ga212ae2f9d975d89621c51fdb9204b2ab":[4,0,0,1231],
+"group__signal__constants.html#ga25e954d589d7f8b4ef549138fdf95840":[4,0,0,1215],
 "group__signal__constants.html#ga25e954d589d7f8b4ef549138fdf95840":[3,53,0,3,21],
-"group__signal__constants.html#ga25e954d589d7f8b4ef549138fdf95840":[4,0,0,1214],
-"group__signal__constants.html#ga26dadbd9fd651454ed2cd9aec27c89d0":[4,0,0,1198],
+"group__signal__constants.html#ga26dadbd9fd651454ed2cd9aec27c89d0":[4,0,0,1199],
 "group__signal__constants.html#ga26dadbd9fd651454ed2cd9aec27c89d0":[3,53,0,3,5],
+"group__signal__constants.html#ga2763655f936f34761b70ba43bad5c63d":[4,0,0,1225],
 "group__signal__constants.html#ga2763655f936f34761b70ba43bad5c63d":[3,53,0,3,31],
-"group__signal__constants.html#ga2763655f936f34761b70ba43bad5c63d":[4,0,0,1224],
-"group__signal__constants.html#ga2ab5265612db9553d78f105c9849bfbe":[4,0,0,1217],
 "group__signal__constants.html#ga2ab5265612db9553d78f105c9849bfbe":[3,53,0,3,24],
-"group__signal__constants.html#ga2d73dee6a914b7760fbddfda0c1f5a01":[4,0,0,1194],
+"group__signal__constants.html#ga2ab5265612db9553d78f105c9849bfbe":[4,0,0,1218],
 "group__signal__constants.html#ga2d73dee6a914b7760fbddfda0c1f5a01":[3,53,0,3,1],
+"group__signal__constants.html#ga2d73dee6a914b7760fbddfda0c1f5a01":[4,0,0,1195],
+"group__signal__constants.html#ga351bab31a52656719e7f81301449e3e6":[4,0,0,1236],
 "group__signal__constants.html#ga351bab31a52656719e7f81301449e3e6":[3,53,0,3,42],
-"group__signal__constants.html#ga351bab31a52656719e7f81301449e3e6":[4,0,0,1235],
-"group__signal__constants.html#ga3d2b5c4187540623d6ea22c5225bdd3a":[4,0,0,1234],
+"group__signal__constants.html#ga3d2b5c4187540623d6ea22c5225bdd3a":[4,0,0,1235],
 "group__signal__constants.html#ga3d2b5c4187540623d6ea22c5225bdd3a":[3,53,0,3,41],
-"group__signal__constants.html#ga4342fb4d1895a224a188b5be0045335b":[4,0,0,1228],
 "group__signal__constants.html#ga4342fb4d1895a224a188b5be0045335b":[3,53,0,3,35],
+"group__signal__constants.html#ga4342fb4d1895a224a188b5be0045335b":[4,0,0,1229],
 "group__signal__constants.html#ga447164e5bdc2f78c152fca2c8ea299d5":[3,53,0,3,45],
-"group__signal__constants.html#ga447164e5bdc2f78c152fca2c8ea299d5":[4,0,0,1238],
+"group__signal__constants.html#ga447164e5bdc2f78c152fca2c8ea299d5":[4,0,0,1239],
+"group__signal__constants.html#ga47d644d04fa2f5023bbb9f55a5d98b01":[4,0,0,1197],
 "group__signal__constants.html#ga47d644d04fa2f5023bbb9f55a5d98b01":[3,53,0,3,3],
-"group__signal__constants.html#ga47d644d04fa2f5023bbb9f55a5d98b01":[4,0,0,1196],
+"group__signal__constants.html#ga4e0349e8aa84fa0b7cf80232e5ed2045":[4,0,0,1223],
 "group__signal__constants.html#ga4e0349e8aa84fa0b7cf80232e5ed2045":[3,53,0,3,29],
-"group__signal__constants.html#ga4e0349e8aa84fa0b7cf80232e5ed2045":[4,0,0,1222],
-"group__signal__constants.html#ga541ed3fe491a37cece6eb74c1db398b0":[4,0,0,1216],
 "group__signal__constants.html#ga541ed3fe491a37cece6eb74c1db398b0":[3,53,0,3,23],
+"group__signal__constants.html#ga541ed3fe491a37cece6eb74c1db398b0":[4,0,0,1217],
 "group__signal__constants.html#ga620029e960ee7a416daff1bf61ef8684":[3,53,0,3,25],
-"group__signal__constants.html#ga620029e960ee7a416daff1bf61ef8684":[4,0,0,1218],
-"group__signal__constants.html#ga650531dfb97191ffb28072f299967fdc":[4,0,0,1205],
+"group__signal__constants.html#ga620029e960ee7a416daff1bf61ef8684":[4,0,0,1219],
+"group__signal__constants.html#ga650531dfb97191ffb28072f299967fdc":[4,0,0,1206],
 "group__signal__constants.html#ga650531dfb97191ffb28072f299967fdc":[3,53,0,3,12],
-"group__signal__constants.html#ga6abd5f39c4f458a3d791c0d3b5289976":[4,0,0,1199],
+"group__signal__constants.html#ga6abd5f39c4f458a3d791c0d3b5289976":[4,0,0,1200],
 "group__signal__constants.html#ga6abd5f39c4f458a3d791c0d3b5289976":[3,53,0,3,6],
 "group__signal__constants.html#ga71be1d2281a0fa350171c12adaa88254":[3,53,0,3,38],
-"group__signal__constants.html#ga71be1d2281a0fa350171c12adaa88254":[4,0,0,1231],
-"group__signal__constants.html#ga8dfb9e90a7d43eb8ed14693d3cef69d5":[4,0,0,1227],
+"group__signal__constants.html#ga71be1d2281a0fa350171c12adaa88254":[4,0,0,1232],
+"group__signal__constants.html#ga8dfb9e90a7d43eb8ed14693d3cef69d5":[4,0,0,1228],
 "group__signal__constants.html#ga8dfb9e90a7d43eb8ed14693d3cef69d5":[3,53,0,3,34],
-"group__signal__constants.html#ga943ce4334d5a4cfa3597c6c581e50b6c":[4,0,0,1226],
+"group__signal__constants.html#ga943ce4334d5a4cfa3597c6c581e50b6c":[4,0,0,1227],
 "group__signal__constants.html#ga943ce4334d5a4cfa3597c6c581e50b6c":[3,53,0,3,33],
-"group__signal__constants.html#gaa23e1d77399d44d5237bf2387fbfeb71":[4,0,0,1197],
+"group__signal__constants.html#gaa23e1d77399d44d5237bf2387fbfeb71":[4,0,0,1198],
 "group__signal__constants.html#gaa23e1d77399d44d5237bf2387fbfeb71":[3,53,0,3,4],
 "group__signal__constants.html#gaa2a903e84e1dadffcc261811913bd552":[3,53,0,3,30],
-"group__signal__constants.html#gaa2a903e84e1dadffcc261811913bd552":[4,0,0,1223],
+"group__signal__constants.html#gaa2a903e84e1dadffcc261811913bd552":[4,0,0,1224],
 "group__signal__constants.html#gaa481ec3f81e7c5d8009706eedea394ff":[3,53,0,3,43],
-"group__signal__constants.html#gaa481ec3f81e7c5d8009706eedea394ff":[4,0,0,1236],
-"group__signal__constants.html#gaa4ff64ecb84ea58efee8d2e1086ff67f":[4,0,0,1201],
+"group__signal__constants.html#gaa481ec3f81e7c5d8009706eedea394ff":[4,0,0,1237],
 "group__signal__constants.html#gaa4ff64ecb84ea58efee8d2e1086ff67f":[3,53,0,3,8],
+"group__signal__constants.html#gaa4ff64ecb84ea58efee8d2e1086ff67f":[4,0,0,1202],
+"group__signal__constants.html#gaa64b81edb492442c84993c3e2d60999a":[4,0,0,1207],
 "group__signal__constants.html#gaa64b81edb492442c84993c3e2d60999a":[3,53,0,3,13],
-"group__signal__constants.html#gaa64b81edb492442c84993c3e2d60999a":[4,0,0,1206],
-"group__signal__constants.html#gaa760f275652fb31f85e31480a4637698":[4,0,0,1202],
+"group__signal__constants.html#gaa760f275652fb31f85e31480a4637698":[4,0,0,1203],
 "group__signal__constants.html#gaa760f275652fb31f85e31480a4637698":[3,53,0,3,9],
 "group__signal__constants.html#gaa891a5a7cc44222d54ea103d940d5454":[3,53,0,3,20],
-"group__signal__constants.html#gaa891a5a7cc44222d54ea103d940d5454":[4,0,0,1213],
+"group__signal__constants.html#gaa891a5a7cc44222d54ea103d940d5454":[4,0,0,1214],
 "group__signal__constants.html#gab42117fc78cb6af6c22136a392943a55":[4,0,0,1020],
 "group__signal__constants.html#gab42117fc78cb6af6c22136a392943a55":[3,53,0,3,0],
-"group__signal__constants.html#gab521aedd9612c8a7617c522f4225ebb6":[4,0,0,1212],
 "group__signal__constants.html#gab521aedd9612c8a7617c522f4225ebb6":[3,53,0,3,19],
+"group__signal__constants.html#gab521aedd9612c8a7617c522f4225ebb6":[4,0,0,1213],
+"group__signal__constants.html#gab6a540f14b42b4b137c2fe1ad70fa0b6":[4,0,0,1216],
 "group__signal__constants.html#gab6a540f14b42b4b137c2fe1ad70fa0b6":[3,53,0,3,22],
-"group__signal__constants.html#gab6a540f14b42b4b137c2fe1ad70fa0b6":[4,0,0,1215],
 "group__signal__constants.html#gabc953d69950a28fe937b4d3b07898b50":[3,53,0,3,27],
-"group__signal__constants.html#gabc953d69950a28fe937b4d3b07898b50":[4,0,0,1220],
-"group__signal__constants.html#gac2320ab15a0ac209b996737f63c881cb":[4,0,0,1209],
+"group__signal__constants.html#gabc953d69950a28fe937b4d3b07898b50":[4,0,0,1221],
 "group__signal__constants.html#gac2320ab15a0ac209b996737f63c881cb":[3,53,0,3,16],
+"group__signal__constants.html#gac2320ab15a0ac209b996737f63c881cb":[4,0,0,1210],
 "group__signal__constants.html#gac3aa3ad8ed6f20bcd925f7aa351b967e":[3,53,0,3,32],
-"group__signal__constants.html#gac3aa3ad8ed6f20bcd925f7aa351b967e":[4,0,0,1225],
-"group__signal__constants.html#gac587eb24af06513dd73790b9186b9afd":[4,0,0,1229],
+"group__signal__constants.html#gac3aa3ad8ed6f20bcd925f7aa351b967e":[4,0,0,1226],
+"group__signal__constants.html#gac587eb24af06513dd73790b9186b9afd":[4,0,0,1230],
 "group__signal__constants.html#gac587eb24af06513dd73790b9186b9afd":[3,53,0,3,36],
+"group__signal__constants.html#gacc8913e44d98b7dcb4bdaf256ea92633":[4,0,0,1234],
 "group__signal__constants.html#gacc8913e44d98b7dcb4bdaf256ea92633":[3,53,0,3,40],
-"group__signal__constants.html#gacc8913e44d98b7dcb4bdaf256ea92633":[4,0,0,1233],
-"group__signal__constants.html#gacee971bf64b5288b7b88b19b87fc985c":[4,0,0,1200],
+"group__signal__constants.html#gacee971bf64b5288b7b88b19b87fc985c":[4,0,0,1201],
 "group__signal__constants.html#gacee971bf64b5288b7b88b19b87fc985c":[3,53,0,3,7],
-"group__signal__constants.html#gad20de530f353b455f409de0d4fb61880":[4,0,0,1208],
 "group__signal__constants.html#gad20de530f353b455f409de0d4fb61880":[3,53,0,3,15],
+"group__signal__constants.html#gad20de530f353b455f409de0d4fb61880":[4,0,0,1209],
 "group__signal__constants.html#gad50860982883d7dffde6d4970f4f249d":[3,53,0,3,44],
-"group__signal__constants.html#gad50860982883d7dffde6d4970f4f249d":[4,0,0,1237],
+"group__signal__constants.html#gad50860982883d7dffde6d4970f4f249d":[4,0,0,1238],
+"group__signal__constants.html#gada22169eb534eed936738dfdcce3d3ac":[4,0,0,1222],
 "group__signal__constants.html#gada22169eb534eed936738dfdcce3d3ac":[3,53,0,3,28],
-"group__signal__constants.html#gada22169eb534eed936738dfdcce3d3ac":[4,0,0,1221],
-"group__signal__constants.html#gadf5acb1f70a6dd74be47bea35edf2f6e":[4,0,0,1210],
+"group__signal__constants.html#gadf5acb1f70a6dd74be47bea35edf2f6e":[4,0,0,1211],
 "group__signal__constants.html#gadf5acb1f70a6dd74be47bea35edf2f6e":[3,53,0,3,17],
-"group__signal__constants.html#gae1574ae772e78b466d74a3ef71e3edfe":[4,0,0,1203],
+"group__signal__constants.html#gae1574ae772e78b466d74a3ef71e3edfe":[4,0,0,1204],
 "group__signal__constants.html#gae1574ae772e78b466d74a3ef71e3edfe":[3,53,0,3,10],
-"group__signal__constants.html#gae1a22383c370f5db5ed244ecf3f0fb06":[4,0,0,1207],
+"group__signal__constants.html#gae1a22383c370f5db5ed244ecf3f0fb06":[4,0,0,1208],
 "group__signal__constants.html#gae1a22383c370f5db5ed244ecf3f0fb06":[3,53,0,3,14],
-"group__signal__constants.html#gafb2c7d6e7edc49f5e72c538cf9ede594":[4,0,0,1211],
+"group__signal__constants.html#gafb2c7d6e7edc49f5e72c538cf9ede594":[4,0,0,1212],
 "group__signal__constants.html#gafb2c7d6e7edc49f5e72c538cf9ede594":[3,53,0,3,18],
+"group__signal__constants.html#gafd6b196e097d02519f301fe2ac2394e5":[4,0,0,1220],
 "group__signal__constants.html#gafd6b196e097d02519f301fe2ac2394e5":[3,53,0,3,26],
-"group__signal__constants.html#gafd6b196e097d02519f301fe2ac2394e5":[4,0,0,1219],
 "group__signal__handling__functions.html":[3,53],
 "group__signal__handling__functions.html#ga28cf2a280f8c3c302eeac0a46030be2d":[4,0,0,666],
 "group__signal__handling__functions.html#ga28cf2a280f8c3c302eeac0a46030be2d":[3,53,2],
@@ -182,44 +184,44 @@ var NAVTREEINDEX14 =
 "group__signal__handling__functions.html#gac05b9fa9ba1c302c9a34995573482a5f":[3,53,1],
 "group__socket__poll__constants.html":[3,30],
 "group__socket__poll__constants.html#ga5a36857f12bf9600d8bbab5ed081c364":[3,30,1],
-"group__socket__poll__constants.html#ga5a36857f12bf9600d8bbab5ed081c364":[4,0,0,1243],
+"group__socket__poll__constants.html#ga5a36857f12bf9600d8bbab5ed081c364":[4,0,0,1244],
+"group__socket__poll__constants.html#ga75f3b24346b734658a9bcc823efa57ae":[4,0,0,1243],
 "group__socket__poll__constants.html#ga75f3b24346b734658a9bcc823efa57ae":[3,30,0],
-"group__socket__poll__constants.html#ga75f3b24346b734658a9bcc823efa57ae":[4,0,0,1242],
 "group__socket__poll__constants.html#gab1e74fb9bafa30f1e6bffb0e1de1dfc4":[3,30,2],
-"group__socket__poll__constants.html#gab1e74fb9bafa30f1e6bffb0e1de1dfc4":[4,0,0,1244],
+"group__socket__poll__constants.html#gab1e74fb9bafa30f1e6bffb0e1de1dfc4":[4,0,0,1245],
 "group__socket__type__constants.html":[3,36],
 "group__socket__type__constants.html#ga658ebfaeb8e533f106b3019ba3007531":[3,36,2],
-"group__socket__type__constants.html#ga658ebfaeb8e533f106b3019ba3007531":[4,0,0,1246],
-"group__socket__type__constants.html#ga670510cf028ecec51705237e1003befb":[4,0,0,1245],
+"group__socket__type__constants.html#ga658ebfaeb8e533f106b3019ba3007531":[4,0,0,1247],
 "group__socket__type__constants.html#ga670510cf028ecec51705237e1003befb":[3,36,1],
+"group__socket__type__constants.html#ga670510cf028ecec51705237e1003befb":[4,0,0,1246],
 "group__socket__type__constants.html#gab4192979e83a6d314821be9e962154f8":[3,36,0],
-"group__socket__type__constants.html#gab4192979e83a6d314821be9e962154f8":[4,0,0,1241],
+"group__socket__type__constants.html#gab4192979e83a6d314821be9e962154f8":[4,0,0,1242],
 "group__sql__constants.html":[3,46,1],
-"group__sql__constants.html#ga223c3ce9da5ccb29dd35eab11f161f9f":[4,0,0,2,48],
 "group__sql__constants.html#ga223c3ce9da5ccb29dd35eab11f161f9f":[3,46,1,5],
-"group__sql__constants.html#ga56cd886db959d27929f4700ab0d9d43a":[4,0,0,2,19],
+"group__sql__constants.html#ga223c3ce9da5ccb29dd35eab11f161f9f":[4,0,0,2,48],
 "group__sql__constants.html#ga56cd886db959d27929f4700ab0d9d43a":[3,46,1,2],
-"group__sql__constants.html#ga85bba3f8e978509f66f08011b264e9b0":[4,0,0,2,38],
+"group__sql__constants.html#ga56cd886db959d27929f4700ab0d9d43a":[4,0,0,2,19],
 "group__sql__constants.html#ga85bba3f8e978509f66f08011b264e9b0":[3,46,1,3],
+"group__sql__constants.html#ga85bba3f8e978509f66f08011b264e9b0":[4,0,0,2,38],
 "group__sql__constants.html#ga8d5c7d08373364f4773f65e69063cd04":[3,46,1,4],
 "group__sql__constants.html#ga8d5c7d08373364f4773f65e69063cd04":[4,0,0,2,47],
 "group__sql__constants.html#ga90979385c781ed49b4f726f32a48a9b5":[3,46,1,7],
 "group__sql__constants.html#ga90979385c781ed49b4f726f32a48a9b5":[4,0,0,2,50],
-"group__sql__constants.html#ga9d23a1d69fcb188296a231a36c6b6da2":[3,46,1,6],
 "group__sql__constants.html#ga9d23a1d69fcb188296a231a36c6b6da2":[4,0,0,2,49],
-"group__sql__constants.html#gac334541e4d6796152ba4d5391efd714f":[3,46,1,0],
+"group__sql__constants.html#ga9d23a1d69fcb188296a231a36c6b6da2":[3,46,1,6],
 "group__sql__constants.html#gac334541e4d6796152ba4d5391efd714f":[4,0,0,2,17],
+"group__sql__constants.html#gac334541e4d6796152ba4d5391efd714f":[3,46,1,0],
 "group__sql__constants.html#gafda425c6fc5962ff8d436c9d30bfaf02":[3,46,1,1],
 "group__sql__constants.html#gafda425c6fc5962ff8d436c9d30bfaf02":[4,0,0,2,18],
 "group__ssl__mode__constants.html":[3,31],
 "group__ssl__mode__constants.html#ga3e03ac75e51a9f4e994518fc3fc69ab7":[3,31,2],
-"group__ssl__mode__constants.html#ga3e03ac75e51a9f4e994518fc3fc69ab7":[4,0,0,1253],
+"group__ssl__mode__constants.html#ga3e03ac75e51a9f4e994518fc3fc69ab7":[4,0,0,1254],
+"group__ssl__mode__constants.html#ga7053aa1b8d954e00530f632c502c91d2":[4,0,0,1253],
 "group__ssl__mode__constants.html#ga7053aa1b8d954e00530f632c502c91d2":[3,31,1],
-"group__ssl__mode__constants.html#ga7053aa1b8d954e00530f632c502c91d2":[4,0,0,1252],
+"group__ssl__mode__constants.html#ga70bdb100f9ffb3564dfc38505740a0cb":[4,0,0,1252],
 "group__ssl__mode__constants.html#ga70bdb100f9ffb3564dfc38505740a0cb":[3,31,0],
-"group__ssl__mode__constants.html#ga70bdb100f9ffb3564dfc38505740a0cb":[4,0,0,1251],
+"group__ssl__mode__constants.html#gae29e3d0203f536c5bf5c0cb225c73c1a":[4,0,0,1255],
 "group__ssl__mode__constants.html#gae29e3d0203f536c5bf5c0cb225c73c1a":[3,31,3],
-"group__ssl__mode__constants.html#gae29e3d0203f536c5bf5c0cb225c73c1a":[4,0,0,1254],
 "group__string__functions.html":[3,57],
 "group__string__functions.html#ga0024906d05096f7f8c1130396dde53c7":[3,57,44],
 "group__string__functions.html#ga0024906d05096f7f8c1130396dde53c7":[4,0,0,594],
@@ -243,11 +245,9 @@ var NAVTREEINDEX14 =
 "group__string__functions.html#ga2230070c2f14ca70e63cf463f5d688c3":[3,57,62],
 "group__string__functions.html#ga2470edb3a13437c060ec85e7653e022a":[4,0,0,502],
 "group__string__functions.html#ga2470edb3a13437c060ec85e7653e022a":[3,57,31],
-"group__string__functions.html#ga25264bfb9950ac66862db9b4a32eeee8":[4,0,0,655],
 "group__string__functions.html#ga25264bfb9950ac66862db9b4a32eeee8":[3,57,60],
+"group__string__functions.html#ga25264bfb9950ac66862db9b4a32eeee8":[4,0,0,655],
 "group__string__functions.html#ga3204bee77dc83e5095f95f6582e591c0":[4,0,0,810],
 "group__string__functions.html#ga3204bee77dc83e5095f95f6582e591c0":[3,57,84],
-"group__string__functions.html#ga32070517a9f8a70a32ef48f83a6f128e":[3,57,47],
-"group__string__functions.html#ga32070517a9f8a70a32ef48f83a6f128e":[4,0,0,609],
-"group__string__functions.html#ga33bb08516773ed10def16bb42d6b8159":[4,0,0,293]
+"group__string__functions.html#ga32070517a9f8a70a32ef48f83a6f128e":[3,57,47]
 };
