@@ -1,5 +1,7 @@
 var NAVTREEINDEX17 =
 {
+"group__type__conversion__functions.html#ga57dc696a2078b28d578b7a034f9ac555":[4,0,0,133],
+"group__type__conversion__functions.html#ga62b00f727549f979c1dc83450d2819a2":[3,60,21],
 "group__type__conversion__functions.html#ga62b00f727549f979c1dc83450d2819a2":[4,0,0,758],
 "group__type__conversion__functions.html#ga7739224e50b4d6ebfc800bbeb34dff5d":[3,60,11],
 "group__type__conversion__functions.html#ga7739224e50b4d6ebfc800bbeb34dff5d":[4,0,0,451],
@@ -7,10 +9,10 @@ var NAVTREEINDEX17 =
 "group__type__conversion__functions.html#ga97015b71e0a9f1118be166fc6465e48e":[4,0,0,452],
 "group__type__conversion__functions.html#gacf16b4126b795f4b6933ef3425cadae3":[4,0,0,759],
 "group__type__conversion__functions.html#gacf16b4126b795f4b6933ef3425cadae3":[3,60,22],
-"group__type__conversion__functions.html#gad41f0cd19b4ebe21cf9562d2708ccabd":[3,60,5],
 "group__type__conversion__functions.html#gad41f0cd19b4ebe21cf9562d2708ccabd":[4,0,0,132],
-"group__type__conversion__functions.html#gada40c7265689dbfa89579beff516489a":[4,0,0,453],
+"group__type__conversion__functions.html#gad41f0cd19b4ebe21cf9562d2708ccabd":[3,60,5],
 "group__type__conversion__functions.html#gada40c7265689dbfa89579beff516489a":[3,60,13],
+"group__type__conversion__functions.html#gada40c7265689dbfa89579beff516489a":[4,0,0,453],
 "group__type__conversion__functions.html#gaedc7dfca9a2bab4770135bb01a34b63c":[3,60,16],
 "group__type__conversion__functions.html#gaedc7dfca9a2bab4770135bb01a34b63c":[4,0,0,482],
 "group__type__conversion__functions.html#gaf11c7f5c43ced1e9b95bd2270ee87ed9":[4,0,0,129],
@@ -23,117 +25,117 @@ var NAVTREEINDEX17 =
 "group__user__and__group__functions.html#ga6be17484ff802389da795f831a549e4e":[4,0,0,431],
 "group__user__and__group__functions.html#ga6be17484ff802389da795f831a549e4e":[3,56,0],
 "group__warning__constants.html":[3,16],
-"group__warning__constants.html#ga01d5b544bf6b6b9a2f536170a0dec874":[4,0,0,1293],
 "group__warning__constants.html#ga01d5b544bf6b6b9a2f536170a0dec874":[3,16,2],
-"group__warning__constants.html#ga123728981ed0a5970536f94bcbcd88b1":[4,0,0,1292],
+"group__warning__constants.html#ga01d5b544bf6b6b9a2f536170a0dec874":[4,0,0,1294],
+"group__warning__constants.html#ga123728981ed0a5970536f94bcbcd88b1":[4,0,0,1293],
 "group__warning__constants.html#ga123728981ed0a5970536f94bcbcd88b1":[3,16,1],
-"group__warning__constants.html#ga23066c3a05c2fe71f38ab685f1bf6b09":[4,0,0,1298],
+"group__warning__constants.html#ga23066c3a05c2fe71f38ab685f1bf6b09":[4,0,0,1299],
 "group__warning__constants.html#ga23066c3a05c2fe71f38ab685f1bf6b09":[3,16,7],
 "group__warning__constants.html#ga2463b44ba4c7437bb45d9c9850bffd3e":[3,16,20],
-"group__warning__constants.html#ga2463b44ba4c7437bb45d9c9850bffd3e":[4,0,0,1311],
-"group__warning__constants.html#ga257188e66b355163c9dedc161e722254":[4,0,0,1305],
+"group__warning__constants.html#ga2463b44ba4c7437bb45d9c9850bffd3e":[4,0,0,1312],
+"group__warning__constants.html#ga257188e66b355163c9dedc161e722254":[4,0,0,1306],
 "group__warning__constants.html#ga257188e66b355163c9dedc161e722254":[3,16,14],
+"group__warning__constants.html#ga597d58a31c59bc47bbecfe8160c57129":[4,0,0,1308],
 "group__warning__constants.html#ga597d58a31c59bc47bbecfe8160c57129":[3,16,16],
-"group__warning__constants.html#ga597d58a31c59bc47bbecfe8160c57129":[4,0,0,1307],
+"group__warning__constants.html#ga5d8afd6e29d7ceba003d8869c2bbe5e1":[4,0,0,1305],
 "group__warning__constants.html#ga5d8afd6e29d7ceba003d8869c2bbe5e1":[3,16,13],
-"group__warning__constants.html#ga5d8afd6e29d7ceba003d8869c2bbe5e1":[4,0,0,1304],
 "group__warning__constants.html#ga664f2aba566e42b153dad3a0caf66a6b":[3,16,5],
-"group__warning__constants.html#ga664f2aba566e42b153dad3a0caf66a6b":[4,0,0,1296],
-"group__warning__constants.html#ga677c5a9e0fdfb07d76c152999fffdc55":[4,0,0,1309],
+"group__warning__constants.html#ga664f2aba566e42b153dad3a0caf66a6b":[4,0,0,1297],
+"group__warning__constants.html#ga677c5a9e0fdfb07d76c152999fffdc55":[4,0,0,1310],
 "group__warning__constants.html#ga677c5a9e0fdfb07d76c152999fffdc55":[3,16,18],
-"group__warning__constants.html#ga7f704aa8f7652702d72d22ce93125566":[4,0,0,1303],
 "group__warning__constants.html#ga7f704aa8f7652702d72d22ce93125566":[3,16,12],
-"group__warning__constants.html#ga82936dc7ad95c220a0b3635618bffea9":[4,0,0,1308],
+"group__warning__constants.html#ga7f704aa8f7652702d72d22ce93125566":[4,0,0,1304],
 "group__warning__constants.html#ga82936dc7ad95c220a0b3635618bffea9":[3,16,17],
+"group__warning__constants.html#ga82936dc7ad95c220a0b3635618bffea9":[4,0,0,1309],
+"group__warning__constants.html#ga8e22cc8dbf206cc7512d89b88b6e2564":[4,0,0,1311],
 "group__warning__constants.html#ga8e22cc8dbf206cc7512d89b88b6e2564":[3,16,19],
-"group__warning__constants.html#ga8e22cc8dbf206cc7512d89b88b6e2564":[4,0,0,1310],
 "group__warning__constants.html#ga9cc566b485af781c2399391757b5ed42":[3,16,4],
-"group__warning__constants.html#ga9cc566b485af781c2399391757b5ed42":[4,0,0,1295],
-"group__warning__constants.html#gaac6499101e41bd5528237e2e8ddd8bf4":[4,0,0,1302],
+"group__warning__constants.html#ga9cc566b485af781c2399391757b5ed42":[4,0,0,1296],
+"group__warning__constants.html#gaac6499101e41bd5528237e2e8ddd8bf4":[4,0,0,1303],
 "group__warning__constants.html#gaac6499101e41bd5528237e2e8ddd8bf4":[3,16,11],
 "group__warning__constants.html#gab247c4239ec72ab1d1d371db02a4885a":[3,16,6],
-"group__warning__constants.html#gab247c4239ec72ab1d1d371db02a4885a":[4,0,0,1297],
-"group__warning__constants.html#gac3e3f433df767225241ac8a79659ac82":[4,0,0,1294],
+"group__warning__constants.html#gab247c4239ec72ab1d1d371db02a4885a":[4,0,0,1298],
+"group__warning__constants.html#gac3e3f433df767225241ac8a79659ac82":[4,0,0,1295],
 "group__warning__constants.html#gac3e3f433df767225241ac8a79659ac82":[3,16,3],
 "group__warning__constants.html#gaca379fa551c754f3c17c8646f0266d3c":[3,16,0],
-"group__warning__constants.html#gaca379fa551c754f3c17c8646f0266d3c":[4,0,0,1291],
-"group__warning__constants.html#gad5de92870336590ea44a7c26f1bf1ca2":[4,0,0,1300],
+"group__warning__constants.html#gaca379fa551c754f3c17c8646f0266d3c":[4,0,0,1292],
 "group__warning__constants.html#gad5de92870336590ea44a7c26f1bf1ca2":[3,16,9],
-"group__warning__constants.html#gad7d5ccb4cca35c2be30baab1e2bf7bf7":[4,0,0,1301],
+"group__warning__constants.html#gad5de92870336590ea44a7c26f1bf1ca2":[4,0,0,1301],
 "group__warning__constants.html#gad7d5ccb4cca35c2be30baab1e2bf7bf7":[3,16,10],
-"group__warning__constants.html#gadab0ec646f61cd37bdc79bb0fc948f79":[4,0,0,1306],
+"group__warning__constants.html#gad7d5ccb4cca35c2be30baab1e2bf7bf7":[4,0,0,1302],
+"group__warning__constants.html#gadab0ec646f61cd37bdc79bb0fc948f79":[4,0,0,1307],
 "group__warning__constants.html#gadab0ec646f61cd37bdc79bb0fc948f79":[3,16,15],
+"group__warning__constants.html#gadf0ad85e6dc336579e482387049a2f56":[4,0,0,1300],
 "group__warning__constants.html#gadf0ad85e6dc336579e482387049a2f56":[3,16,8],
-"group__warning__constants.html#gadf0ad85e6dc336579e482387049a2f56":[4,0,0,1299],
 "group__x509__verification__constants.html":[3,32],
+"group__x509__verification__constants.html#ga0194c30188610d8aef7df4a98d2583ba":[4,0,0,1321],
 "group__x509__verification__constants.html#ga0194c30188610d8aef7df4a98d2583ba":[3,32,8],
-"group__x509__verification__constants.html#ga0194c30188610d8aef7df4a98d2583ba":[4,0,0,1320],
-"group__x509__verification__constants.html#ga04e25fb5ed66b37b280758ed17cce0f9":[4,0,0,1318],
 "group__x509__verification__constants.html#ga04e25fb5ed66b37b280758ed17cce0f9":[3,32,6],
+"group__x509__verification__constants.html#ga04e25fb5ed66b37b280758ed17cce0f9":[4,0,0,1319],
 "group__x509__verification__constants.html#ga0d28ad9c54f79922715013bca49f4a52":[3,32,0],
-"group__x509__verification__constants.html#ga0d28ad9c54f79922715013bca49f4a52":[4,0,0,1312],
+"group__x509__verification__constants.html#ga0d28ad9c54f79922715013bca49f4a52":[4,0,0,1313],
 "group__x509__verification__constants.html#ga0ebd0784741e7d3521e972da7f294aba":[3,32,33],
-"group__x509__verification__constants.html#ga0ebd0784741e7d3521e972da7f294aba":[4,0,0,1345],
+"group__x509__verification__constants.html#ga0ebd0784741e7d3521e972da7f294aba":[4,0,0,1346],
 "group__x509__verification__constants.html#ga1c827ab82254df93dfc83b22d764dba6":[3,32,15],
-"group__x509__verification__constants.html#ga1c827ab82254df93dfc83b22d764dba6":[4,0,0,1327],
+"group__x509__verification__constants.html#ga1c827ab82254df93dfc83b22d764dba6":[4,0,0,1328],
+"group__x509__verification__constants.html#ga1e7f2975f18582ef16903119a9c932d5":[4,0,0,1335],
 "group__x509__verification__constants.html#ga1e7f2975f18582ef16903119a9c932d5":[3,32,22],
-"group__x509__verification__constants.html#ga1e7f2975f18582ef16903119a9c932d5":[4,0,0,1334],
 "group__x509__verification__constants.html#ga2163d9e78be7ed6ffdd8d1e9ae5c1331":[3,32,20],
-"group__x509__verification__constants.html#ga2163d9e78be7ed6ffdd8d1e9ae5c1331":[4,0,0,1332],
+"group__x509__verification__constants.html#ga2163d9e78be7ed6ffdd8d1e9ae5c1331":[4,0,0,1333],
 "group__x509__verification__constants.html#ga236bc06dac524bcb9a61180e568bc462":[3,32,19],
-"group__x509__verification__constants.html#ga236bc06dac524bcb9a61180e568bc462":[4,0,0,1331],
+"group__x509__verification__constants.html#ga236bc06dac524bcb9a61180e568bc462":[4,0,0,1332],
+"group__x509__verification__constants.html#ga2f48578acd358ebfe55100f6daf1602b":[4,0,0,1315],
 "group__x509__verification__constants.html#ga2f48578acd358ebfe55100f6daf1602b":[3,32,2],
-"group__x509__verification__constants.html#ga2f48578acd358ebfe55100f6daf1602b":[4,0,0,1314],
 "group__x509__verification__constants.html#ga345ab69e53100f9349d9a38877bb44ca":[3,32,13],
-"group__x509__verification__constants.html#ga345ab69e53100f9349d9a38877bb44ca":[4,0,0,1325],
-"group__x509__verification__constants.html#ga4a67994a701467704c8900ec6b0a42c6":[4,0,0,1338],
+"group__x509__verification__constants.html#ga345ab69e53100f9349d9a38877bb44ca":[4,0,0,1326],
 "group__x509__verification__constants.html#ga4a67994a701467704c8900ec6b0a42c6":[3,32,26],
-"group__x509__verification__constants.html#ga54fe67c0c13ae6dfeb20ea2f197be267":[4,0,0,1340],
+"group__x509__verification__constants.html#ga4a67994a701467704c8900ec6b0a42c6":[4,0,0,1339],
 "group__x509__verification__constants.html#ga54fe67c0c13ae6dfeb20ea2f197be267":[3,32,28],
+"group__x509__verification__constants.html#ga54fe67c0c13ae6dfeb20ea2f197be267":[4,0,0,1341],
 "group__x509__verification__constants.html#ga5ef6a3725dcb9fff52ac9fabda19469b":[3,32,32],
-"group__x509__verification__constants.html#ga5ef6a3725dcb9fff52ac9fabda19469b":[4,0,0,1344],
+"group__x509__verification__constants.html#ga5ef6a3725dcb9fff52ac9fabda19469b":[4,0,0,1345],
 "group__x509__verification__constants.html#ga757330b3e07026d87148774bd15eefa4":[3,32,11],
-"group__x509__verification__constants.html#ga757330b3e07026d87148774bd15eefa4":[4,0,0,1323],
+"group__x509__verification__constants.html#ga757330b3e07026d87148774bd15eefa4":[4,0,0,1324],
 "group__x509__verification__constants.html#ga78a4220220d45411835ef8601b8294bb":[3,32,3],
-"group__x509__verification__constants.html#ga78a4220220d45411835ef8601b8294bb":[4,0,0,1315],
+"group__x509__verification__constants.html#ga78a4220220d45411835ef8601b8294bb":[4,0,0,1316],
+"group__x509__verification__constants.html#ga7f6fe4a2dd47539540e2919e464e528d":[4,0,0,1343],
 "group__x509__verification__constants.html#ga7f6fe4a2dd47539540e2919e464e528d":[3,32,30],
-"group__x509__verification__constants.html#ga7f6fe4a2dd47539540e2919e464e528d":[4,0,0,1342],
-"group__x509__verification__constants.html#ga86aaa114c74aab441847ad4db7597a6f":[4,0,0,1343],
 "group__x509__verification__constants.html#ga86aaa114c74aab441847ad4db7597a6f":[3,32,31],
+"group__x509__verification__constants.html#ga86aaa114c74aab441847ad4db7597a6f":[4,0,0,1344],
+"group__x509__verification__constants.html#ga88ea09360717cf145bdd190c3e132c7d":[4,0,0,1338],
 "group__x509__verification__constants.html#ga88ea09360717cf145bdd190c3e132c7d":[3,32,25],
-"group__x509__verification__constants.html#ga88ea09360717cf145bdd190c3e132c7d":[4,0,0,1337],
 "group__x509__verification__constants.html#gaa00c30bf61fbe3924d06c96c3d20e7d9":[3,32,17],
-"group__x509__verification__constants.html#gaa00c30bf61fbe3924d06c96c3d20e7d9":[4,0,0,1329],
+"group__x509__verification__constants.html#gaa00c30bf61fbe3924d06c96c3d20e7d9":[4,0,0,1330],
 "group__x509__verification__constants.html#gaa6c7200e8827c8664172575c70683754":[3,32,16],
-"group__x509__verification__constants.html#gaa6c7200e8827c8664172575c70683754":[4,0,0,1328],
+"group__x509__verification__constants.html#gaa6c7200e8827c8664172575c70683754":[4,0,0,1329],
 "group__x509__verification__constants.html#gaaab55b073ffb0af920c408a7c6c18bc3":[3,32,7],
-"group__x509__verification__constants.html#gaaab55b073ffb0af920c408a7c6c18bc3":[4,0,0,1319],
-"group__x509__verification__constants.html#gaad87fc6ed5543a647eccdae0a98349d8":[4,0,0,1336],
+"group__x509__verification__constants.html#gaaab55b073ffb0af920c408a7c6c18bc3":[4,0,0,1320],
 "group__x509__verification__constants.html#gaad87fc6ed5543a647eccdae0a98349d8":[3,32,24],
-"group__x509__verification__constants.html#gab638296ef4610b30d0660fa13e045954":[4,0,0,1330],
+"group__x509__verification__constants.html#gaad87fc6ed5543a647eccdae0a98349d8":[4,0,0,1337],
 "group__x509__verification__constants.html#gab638296ef4610b30d0660fa13e045954":[3,32,18],
-"group__x509__verification__constants.html#gac1ace11411b4a1bfd915c2322d04136e":[4,0,0,1333],
+"group__x509__verification__constants.html#gab638296ef4610b30d0660fa13e045954":[4,0,0,1331],
 "group__x509__verification__constants.html#gac1ace11411b4a1bfd915c2322d04136e":[3,32,21],
+"group__x509__verification__constants.html#gac1ace11411b4a1bfd915c2322d04136e":[4,0,0,1334],
+"group__x509__verification__constants.html#gac348670d2763dc7bce25889c1c9694ec":[4,0,0,1342],
 "group__x509__verification__constants.html#gac348670d2763dc7bce25889c1c9694ec":[3,32,29],
-"group__x509__verification__constants.html#gac348670d2763dc7bce25889c1c9694ec":[4,0,0,1341],
 "group__x509__verification__constants.html#gace0346e494d1793f0524bcd534f43f7f":[3,32,10],
-"group__x509__verification__constants.html#gace0346e494d1793f0524bcd534f43f7f":[4,0,0,1322],
+"group__x509__verification__constants.html#gace0346e494d1793f0524bcd534f43f7f":[4,0,0,1323],
 "group__x509__verification__constants.html#gad8effb53d699713577403dbd93d18940":[3,32,9],
-"group__x509__verification__constants.html#gad8effb53d699713577403dbd93d18940":[4,0,0,1321],
+"group__x509__verification__constants.html#gad8effb53d699713577403dbd93d18940":[4,0,0,1322],
 "group__x509__verification__constants.html#gadd182b1dd774f8c4181f9147991afb3a":[3,32,5],
-"group__x509__verification__constants.html#gadd182b1dd774f8c4181f9147991afb3a":[4,0,0,1317],
-"group__x509__verification__constants.html#gadde3ff8cecf56d2ef5473bc279e8910c":[4,0,0,1326],
+"group__x509__verification__constants.html#gadd182b1dd774f8c4181f9147991afb3a":[4,0,0,1318],
+"group__x509__verification__constants.html#gadde3ff8cecf56d2ef5473bc279e8910c":[4,0,0,1327],
 "group__x509__verification__constants.html#gadde3ff8cecf56d2ef5473bc279e8910c":[3,32,14],
-"group__x509__verification__constants.html#gae1e5481186ecefe9b89d5e2387084fb1":[4,0,0,1339],
+"group__x509__verification__constants.html#gae1e5481186ecefe9b89d5e2387084fb1":[4,0,0,1340],
 "group__x509__verification__constants.html#gae1e5481186ecefe9b89d5e2387084fb1":[3,32,27],
-"group__x509__verification__constants.html#gae6407bd35520f45e29800b396e7e7dc2":[4,0,0,1316],
+"group__x509__verification__constants.html#gae6407bd35520f45e29800b396e7e7dc2":[4,0,0,1317],
 "group__x509__verification__constants.html#gae6407bd35520f45e29800b396e7e7dc2":[3,32,4],
-"group__x509__verification__constants.html#gaea4002870f0a1df88999dfc925243b95":[4,0,0,1313],
+"group__x509__verification__constants.html#gaea4002870f0a1df88999dfc925243b95":[4,0,0,1314],
 "group__x509__verification__constants.html#gaea4002870f0a1df88999dfc925243b95":[3,32,1],
 "group__x509__verification__constants.html#gaf1c08de19215f3800a41504bda25c20d":[3,32,23],
-"group__x509__verification__constants.html#gaf1c08de19215f3800a41504bda25c20d":[4,0,0,1335],
+"group__x509__verification__constants.html#gaf1c08de19215f3800a41504bda25c20d":[4,0,0,1336],
 "group__x509__verification__constants.html#gaf5306ef80a14597259e706c143b41796":[3,32,12],
-"group__x509__verification__constants.html#gaf5306ef80a14597259e706c143b41796":[4,0,0,1324],
+"group__x509__verification__constants.html#gaf5306ef80a14597259e706c143b41796":[4,0,0,1325],
 "hashdecl.html":[0,27],
 "hashdecl.html#hashdecl_creation":[0,27,2],
 "hashdecl.html#hashdecl_object_comparison":[0,27,4],
@@ -247,7 +249,5 @@ var NAVTREEINDEX17 =
 "namespace_qore.html#ae2beafb85bdfb88495f1645605a96b0a":[4,0,0,464],
 "namespace_qore.html#ae45b3134a21e8efc465c469bbe6b58d7":[4,0,0,397],
 "namespace_qore.html#ae504e6dff1aa04fab954b492830df193":[4,0,0,395],
-"namespace_qore.html#ae6dd9a1ccae25a097d61cf0575161075":[4,0,0,751],
-"namespace_qore.html#ae895213e0d9f207ab855e4546c791909":[4,0,0,771],
-"namespace_qore.html#aeb017e3b5ea8ff39e270e844f280e32b":[4,0,0,752]
+"namespace_qore.html#ae6dd9a1ccae25a097d61cf0575161075":[4,0,0,751]
 };
