@@ -1,5 +1,7 @@
 var NAVTREEINDEX18 =
 {
+"namespace_qore.html#ae895213e0d9f207ab855e4546c791909":[4,0,0,771],
+"namespace_qore.html#aeb017e3b5ea8ff39e270e844f280e32b":[4,0,0,752],
 "namespace_qore.html#af04a8a04f9130664f938cf7dc10dbaed":[4,0,0,496],
 "namespace_qore.html#af410921677bddb4e52d5dfe981ada25e":[4,0,0,378],
 "namespace_qore.html#af9b9660d3eaaa087df1681f905936622":[4,0,0,246],
@@ -9,8 +11,8 @@ var NAVTREEINDEX18 =
 "namespace_qore_1_1_s_q_l.html":[4,0,0,2],
 "namespace_qore_1_1_thread.html":[4,0,0,3],
 "namespace_qore_1_1_type.html":[4,0,0,4],
-"namespacemembers.html":[4,1,0],
 "namespacemembers.html":[4,1,0,0],
+"namespacemembers.html":[4,1,0],
 "namespacemembers_a.html":[4,1,0,1],
 "namespacemembers_b.html":[4,1,0,2],
 "namespacemembers_c.html":[4,1,0,3],
@@ -247,7 +249,5 @@ var NAVTREEINDEX18 =
 "parse_directives.html#no-transient":[0,33,72],
 "parse_directives.html#no-uncontrolled-apis":[0,33,73],
 "parse_directives.html#old-style":[0,33,45],
-"parse_directives.html#perl-bool-eval":[0,33,74],
-"parse_directives.html#push-parse-options":[0,33,75],
-"parse_directives.html#require-dollar":[0,33,76]
+"parse_directives.html#perl-bool-eval":[0,33,74]
 };
