@@ -195,9 +195,9 @@ var NAVTREEINDEX6 =
 "group___string_concat_encoding.html#gadb85427aabfa0641ebfd5ac5186e5d9e":[3,53,0,1,4],
 "group__boolean__constants.html":[3,19],
 "group__boolean__constants.html#ga3ba2df91713a6249449347131ea526c3":[3,19,1],
-"group__boolean__constants.html#ga3ba2df91713a6249449347131ea526c3":[4,0,0,1266],
-"group__boolean__constants.html#ga9da2b9a8003cd3788e48305f8a00540f":[3,19,0],
+"group__boolean__constants.html#ga3ba2df91713a6249449347131ea526c3":[4,0,0,1267],
 "group__boolean__constants.html#ga9da2b9a8003cd3788e48305f8a00540f":[4,0,0,994],
+"group__boolean__constants.html#ga9da2b9a8003cd3788e48305f8a00540f":[3,19,0],
 "group__breakpoint__policy__options.html":[3,2],
 "group__breakpoint__policy__options.html#ga8366f69a68ba80c2e6c4e590ffe704cd":[3,2,2],
 "group__breakpoint__policy__options.html#ga8366f69a68ba80c2e6c4e590ffe704cd":[4,0,0,836],
@@ -220,7 +220,7 @@ var NAVTREEINDEX6 =
 "group__compression__constants.html#gacba7ff553151bfe51acca63193990a0c":[3,43,0,1],
 "group__compression__constants.html#gacba7ff553151bfe51acca63193990a0c":[4,0,0,861],
 "group__compression__constants.html#gad0d06df5b25e4e03ca74b6458626d913":[3,43,0,2],
-"group__compression__constants.html#gad0d06df5b25e4e03ca74b6458626d913":[4,0,0,1346],
+"group__compression__constants.html#gad0d06df5b25e4e03ca74b6458626d913":[4,0,0,1347],
 "group__compression__transformations.html":[3,43,1],
 "group__compression__transformations.html#ga0792440b22963ae236ed21a9396f840e":[3,43,1,1],
 "group__compression__transformations.html#ga0792440b22963ae236ed21a9396f840e":[4,0,0,859],
@@ -239,15 +239,15 @@ var NAVTREEINDEX6 =
 "group__compresssion__functions.html#ga2a5264cac8dfd0b95b4706f122c4a5cb":[3,43,6],
 "group__compresssion__functions.html#ga2a9f569fd6d7f90bb6d4e4d99b724105":[4,0,0,193],
 "group__compresssion__functions.html#ga2a9f569fd6d7f90bb6d4e4d99b724105":[3,43,11],
-"group__compresssion__functions.html#ga324723f7a61a79d2ec18b4c871c062bd":[4,0,0,442],
 "group__compresssion__functions.html#ga324723f7a61a79d2ec18b4c871c062bd":[3,43,16],
+"group__compresssion__functions.html#ga324723f7a61a79d2ec18b4c871c062bd":[4,0,0,442],
 "group__compresssion__functions.html#ga4a4dc4e883ee617bc05418daf884bca1":[3,43,14],
 "group__compresssion__functions.html#ga4a4dc4e883ee617bc05418daf884bca1":[4,0,0,440],
 "group__compresssion__functions.html#ga4a509ab986c4592aa8109cf3ec98fa8b":[4,0,0,143],
 "group__compresssion__functions.html#ga4a509ab986c4592aa8109cf3ec98fa8b":[3,43,3],
-"group__compresssion__functions.html#ga55081981dc37ac4a0ba9b03b8453b09b":[4,0,0,445],
 "group__compresssion__functions.html#ga55081981dc37ac4a0ba9b03b8453b09b":[3,43,19],
+"group__compresssion__functions.html#ga55081981dc37ac4a0ba9b03b8453b09b":[4,0,0,445],
 "group__compresssion__functions.html#ga5684efdbe38373331255d4984ef13c9d":[4,0,0,443],
 "group__compresssion__functions.html#ga5684efdbe38373331255d4984ef13c9d":[3,43,17],
-"group__compresssion__functions.html#ga5a7dd18fde0559da33f14f484656cad7":[4,0,0,191]
+"group__compresssion__functions.html#ga5a7dd18fde0559da33f14f484656cad7":[3,43,9]
 };
