@@ -1,5 +1,6 @@
 var NAVTREEINDEX10 =
 {
+"class_qore_string_node.html#a03fcdeea5e243d3689be98d44924d686":[8,0,131,34],
 "class_qore_string_node.html#a117ead03fc3742923dc70e388a15e067":[8,0,131,32],
 "class_qore_string_node.html#a21ac1c525b778e443b1606666cc21b42":[8,0,131,17],
 "class_qore_string_node.html#a21f8951d8d36d1f31f6f09204abc4ff2":[8,0,131,33],
@@ -248,6 +249,5 @@ var NAVTREEINDEX10 =
 "class_system_environment.html#abebc6215148fe49d969448942130fdfc":[8,0,162,7],
 "class_temp_encoding_helper.html":[8,0,163],
 "class_temp_encoding_helper.html#a04677407f9b09ba256cfab96177a1f71":[8,0,163,1],
-"class_temp_encoding_helper.html#a1277f5a7f097df15edb578d2079f074d":[8,0,163,7],
-"class_temp_encoding_helper.html#a1f36adf3870750fcd3f08684ce0f306f":[8,0,163,3]
+"class_temp_encoding_helper.html#a1277f5a7f097df15edb578d2079f074d":[8,0,163,7]
 };
