@@ -1,5 +1,6 @@
 var NAVTREEINDEX4 =
 {
+"class_opt_locker.html#a004d0a25616008513a8094ab070f7e35":[8,0,39,0],
 "class_opt_locker.html#abd615a37121151192fa333411897112e":[8,0,39,1],
 "class_opt_locker.html#ac2adcaabf369999862025b196531669c":[8,0,39,2],
 "class_output_stream.html":[8,0,40],
@@ -248,6 +249,5 @@ var NAVTREEINDEX4 =
 "class_qore_counter.html#ab7c71f4f98d8b4355b3fc86b08d48743":[8,0,68,0],
 "class_qore_debug_program.html":[8,0,69],
 "class_qore_debug_program.html#a0369f2b87e64b9df695d087005f18bc3":[8,0,69,7],
-"class_qore_debug_program.html#a0e18eceac1ceb011e10207dc488319a5":[8,0,69,9],
-"class_qore_debug_program.html#a3d6773e3f46d6b47515e103aa125b8ae":[8,0,69,3]
+"class_qore_debug_program.html#a0e18eceac1ceb011e10207dc488319a5":[8,0,69,9]
 };
