@@ -1,5 +1,6 @@
 var NAVTREEINDEX5 =
 {
+"class_qore_debug_program.html#a3d6773e3f46d6b47515e103aa125b8ae":[8,0,69,3],
 "class_qore_debug_program.html#a3e10fee97bc6dfccb5acf213370b83f1":[8,0,69,2],
 "class_qore_debug_program.html#a3e49b2a22b0d23d3667aefcc4159a8e9":[8,0,69,4],
 "class_qore_debug_program.html#a52b6b0372529dbf05154054153060f59":[8,0,69,8],
@@ -248,6 +249,5 @@ var NAVTREEINDEX5 =
 "class_qore_ftp_client.html#aef1a1ba5ec6390ebed4573c364b3b46f":[8,0,88,15],
 "class_qore_ftp_client.html#af2974dc45b5f920b635a6ead5accf547":[8,0,88,10],
 "class_qore_ftp_client.html#af96e28b18fb11091a9df38192efd368d":[8,0,88,0],
-"class_qore_ftp_client.html#afc2f1052ce8121064a089849c45ccdf6":[8,0,88,3],
-"class_qore_h_t_t_p_client.html":[8,0,90]
+"class_qore_ftp_client.html#afc2f1052ce8121064a089849c45ccdf6":[8,0,88,3]
 };
