@@ -1,5 +1,6 @@
 var NAVTREEINDEX6 =
 {
+"class_qore_h_t_t_p_client.html":[8,0,90],
 "class_qore_h_t_t_p_client.html#a3d15d700dc9030270f3b5ee035646eb2":[8,0,90,1],
 "class_qore_h_t_t_p_client.html#a92123163306c695854f61df937855aad":[8,0,90,0],
 "class_qore_hash_node.html":[8,0,89],
@@ -248,6 +249,5 @@ var NAVTREEINDEX6 =
 "class_qore_namespace_class_iterator.html#a7f6f2b132b4a4f8b40443c7c28cc70d9":[8,0,98,0],
 "class_qore_namespace_const_iterator.html":[8,0,100],
 "class_qore_namespace_const_iterator.html#a301d3b771a2994621bf2049f6647b252":[8,0,100,1],
-"class_qore_namespace_const_iterator.html#a3c9349f022da71d2b3a73347c66e27a2":[8,0,100,0],
-"class_qore_namespace_const_iterator.html#a4dd55efcdea910fff211a6ebf257a18f":[8,0,100,5]
+"class_qore_namespace_const_iterator.html#a3c9349f022da71d2b3a73347c66e27a2":[8,0,100,0]
 };
