@@ -1,5 +1,6 @@
 var NAVTREEINDEX7 =
 {
+"class_qore_namespace_const_iterator.html#a4dd55efcdea910fff211a6ebf257a18f":[8,0,100,5],
 "class_qore_namespace_const_iterator.html#acb8ce2dd60a743f0cdd4f0437cd1febb":[8,0,100,4],
 "class_qore_namespace_const_iterator.html#adf4c84dfef48831618a2cece63fb98a9":[8,0,100,2],
 "class_qore_namespace_const_iterator.html#aec84afc3247f2ea919d789e48b04778b":[8,0,100,3],
@@ -248,6 +249,5 @@ var NAVTREEINDEX7 =
 "class_qore_program.html#a4c09b99a824afd99d58633610797b8e5":[8,0,113,42],
 "class_qore_program.html#a4d4ec7447b7f1a264e486161fa7ccf26":[8,0,113,68],
 "class_qore_program.html#a4d979040273a12f18a0c9bc583ec72b8":[8,0,113,17],
-"class_qore_program.html#a4e4a1bc22cb2cee9a37fe4e40d1fd3b6":[8,0,113,44],
-"class_qore_program.html#a4f1562e080d95ea152026e2db3f3d294":[8,0,113,16]
+"class_qore_program.html#a4e4a1bc22cb2cee9a37fe4e40d1fd3b6":[8,0,113,44]
 };
