@@ -1,5 +1,6 @@
 var NAVTREEINDEX8 =
 {
+"class_qore_program.html#a4f1562e080d95ea152026e2db3f3d294":[8,0,113,16],
 "class_qore_program.html#a518139c22a90965b8b2f8243afa08a02":[8,0,113,3],
 "class_qore_program.html#a55c3801d29059da66ae709ea32589fab":[8,0,113,11],
 "class_qore_program.html#a5980c9195ec92683727a6c2a2074fc06":[8,0,113,37],
@@ -248,6 +249,5 @@ var NAVTREEINDEX8 =
 "class_qore_socket.html#aab9cc0ffac37631260c87b747e9a2220":[8,0,122,112],
 "class_qore_socket.html#ab0574aad1598d70918d955e2f693bb1b":[8,0,122,124],
 "class_qore_socket.html#ab5f304d137496ee3eabbb5c2fd151dd7":[8,0,122,87],
-"class_qore_socket.html#aba84fd68e5ca40f1679dec559375a2d3":[8,0,122,50],
-"class_qore_socket.html#abfa34d519a1ddf0946b06e1bb2d6877e":[8,0,122,16]
+"class_qore_socket.html#aba84fd68e5ca40f1679dec559375a2d3":[8,0,122,50]
 };
