@@ -1,5 +1,6 @@
 var NAVTREEINDEX9 =
 {
+"class_qore_socket.html#abfa34d519a1ddf0946b06e1bb2d6877e":[8,0,122,16],
 "class_qore_socket.html#abfde0d70bbf6f4993ee316e503a1a2a3":[8,0,122,111],
 "class_qore_socket.html#ac0c67c9ca13d9fdf375a10935d6b0304":[8,0,122,99],
 "class_qore_socket.html#ac11befb44926244f5b1136bde34a1b2f":[8,0,122,107],
@@ -248,6 +249,5 @@ var NAVTREEINDEX9 =
 "class_qore_string.html#afedc6a10c2be2546f841eb0939a09b23":[8,0,130,12],
 "class_qore_string.html#affbb506cea1b15e8035fe2ba32abc0a8":[8,0,130,17],
 "class_qore_string_node.html":[8,0,131],
-"class_qore_string_node.html#a0004983b6dd4117ab9892323e95bccfe":[8,0,131,8],
-"class_qore_string_node.html#a03fcdeea5e243d3689be98d44924d686":[8,0,131,34]
+"class_qore_string_node.html#a0004983b6dd4117ab9892323e95bccfe":[8,0,131,8]
 };
