@@ -1,6 +1,10 @@
 var class_aws_rest_client_1_1_aws_rest_client =
 [
     [ "constructor", "class_aws_rest_client_1_1_aws_rest_client.html#a0185dab82a1c0e406bb116084b750add", null ],
+    [ "constructor", "class_aws_rest_client_1_1_aws_rest_client.html#a6b962b72b47134e8a117c043965222f5", null ],
+    [ "getConnectionSchemeInfoImpl", "class_aws_rest_client_1_1_aws_rest_client.html#a4717b30d1fb2cb00b5830ea48ac70df3", null ],
+    [ "getImpl", "class_aws_rest_client_1_1_aws_rest_client.html#a747f83b100502ed59ea8b9632d3e3d5f", null ],
+    [ "getType", "class_aws_rest_client_1_1_aws_rest_client.html#ac0e5fd3d88b7ee1509e05796a04124bb", null ],
     [ "AwsSignatureAlgorithm", "class_aws_rest_client_1_1_aws_rest_client.html#aeba9d4956c86c0c92e8eb43f7ec3bd4a", null ],
     [ "AwsTermination", "class_aws_rest_client_1_1_aws_rest_client.html#ae9e06a9694471b369a604912366fa1d5", null ],
     [ "DefaultSendEncoding", "class_aws_rest_client_1_1_aws_rest_client.html#a7d9a57badc4375284bf266c8860e5a49", null ],
