@@ -56,10 +56,10 @@ var NAVTREEINDEX =
 "annotated.html",
 "group__date__and__time__functions.html#ga83e582adb5ad1401911345ba306dabd2",
 "group__file__locking__constants.html#ga6df55e6d2cd8d49cb714afe15f4d6b63",
-"group__misc__functions.html#ga186059954046920e50aa418739638b8e",
-"group__parse__options.html#ga88a927479c495b99209a6397ef67c240",
-"group__tattr__control__character__constants.html#ga43c58434668c6190c7a3fa2c93a1069a",
-"namespacemembers_vars.html"
+"group__misc__functions.html#ga11da5fd06dcfa57a48a5381268a52086",
+"group__parse__options.html#ga889aa80f8ab33266c165478b5fe3c279",
+"group__tattr__control__character__constants.html#ga36824df04eb03f180576584315d1438f",
+"namespacemembers_func.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
