@@ -1,8 +1,5 @@
 var NAVTREEINDEX6 =
 {
-"namespace_cds_rest_data_provider.html#ae6a4ae4cc0aea2f841a09e8ef74dad0e":[2,0,1,4],
-"namespace_cds_rest_data_provider.html#afe2f823fb387a878b29c96b176383093":[2,0,1,5],
-"namespacemembers.html":[2,1,0],
 "namespacemembers_func.html":[2,1,1],
 "namespacemembers_vars.html":[2,1,2],
 "namespaces.html":[2,0],
