@@ -20,6 +20,7 @@ var namespace_data_provider =
     [ "DataProviderPipeline", "class_data_provider_1_1_data_provider_pipeline.html", "class_data_provider_1_1_data_provider_pipeline" ],
     [ "DataProviderPipelineFactory", "class_data_provider_1_1_data_provider_pipeline_factory.html", "class_data_provider_1_1_data_provider_pipeline_factory" ],
     [ "DataProviderSignatureTypeInfo", "struct_data_provider_1_1_data_provider_signature_type_info.html", "struct_data_provider_1_1_data_provider_signature_type_info" ],
+    [ "DataProviderSummaryInfo", "struct_data_provider_1_1_data_provider_summary_info.html", "struct_data_provider_1_1_data_provider_summary_info" ],
     [ "DataProviderTypeCache", "class_data_provider_1_1_data_provider_type_cache.html", "class_data_provider_1_1_data_provider_type_cache" ],
     [ "DataProviderTypeEntry", "class_data_provider_1_1_data_provider_type_entry.html", "class_data_provider_1_1_data_provider_type_entry" ],
     [ "DataProviderTypeEntryInfo", "struct_data_provider_1_1_data_provider_type_entry_info.html", "struct_data_provider_1_1_data_provider_type_entry_info" ],
@@ -98,14 +99,16 @@ var namespace_data_provider =
     [ "dp_op_ne", "namespace_data_provider.html#a8acc6fd3eddc51adc42e95cb38b9faa8", null ],
     [ "dp_op_not", "namespace_data_provider.html#a84d55503a3274c1377f7e6b94743ca0b", null ],
     [ "dp_op_regex", "namespace_data_provider.html#a8356adb323d7ab6c787b7344db4661f5", null ],
-    [ "elems", "namespace_data_provider.html#a4bb6666e765789f1b6e9afa311068195", null ],
     [ "AbstractDataProviderTypeMap", "namespace_data_provider.html#a9a5a795ede30c8e9c3c4b7da14c376c3", null ],
     [ "DataProviderSignatureAnyType", "namespace_data_provider.html#aa0f33d609a461fdaaca22e4be824c4b8", null ],
     [ "DataProviderSignatureBoolType", "namespace_data_provider.html#a888f587fb265e74db6eb3facb40a2950", null ],
+    [ "DataProviderSignatureDateType", "namespace_data_provider.html#a352e6fcdfe99598e2f8ce1d7f42b974e", null ],
     [ "DataProviderSignatureFieldType", "namespace_data_provider.html#a8145185ec847aa58de3d4d59a429af4c", null ],
+    [ "DataProviderSignatureHashValueType", "namespace_data_provider.html#a3dc085788ac69d27009e8e672d203a54", null ],
     [ "DataProviderSignatureIntValueType", "namespace_data_provider.html#afa4ac1d3ed96eda27807373121922ae0", null ],
     [ "DataProviderSignatureListValueType", "namespace_data_provider.html#a9af8e56ec6792893a014aa7e88e49668", null ],
     [ "DataProviderSignatureOptionalIntValueType", "namespace_data_provider.html#a1f922a9df6217247912ba3b0542b0ee2", null ],
+    [ "DataProviderSignatureOptionalStringValueType", "namespace_data_provider.html#a626e04cae22b724cebd17dd2f1fae99e", null ],
     [ "DataProviderSignatureStringType", "namespace_data_provider.html#a27b67b166003b6242e1ffd3766f75123", null ],
     [ "DataProviderSignatureStringValueType", "namespace_data_provider.html#a9d3d58a5fdf30e55e9e544a61b7639a4", null ],
     [ "DataTypeMap", "namespace_data_provider.html#a1cf50c6d0d820d1fef1fa6d96dc10286", null ],
@@ -130,6 +133,7 @@ var namespace_data_provider =
     [ "DTT_FromFile", "namespace_data_provider.html#a8c33b44c1d10d6717443cc74328b6b20", null ],
     [ "DTT_FromLocation", "namespace_data_provider.html#a4c766723e4735321c7726ca574e13314", null ],
     [ "ER_All", "namespace_data_provider.html#a064c0d1f27aa04752971b68af69543c7", null ],
+    [ "ER_Field", "namespace_data_provider.html#ae064efa9126c48c9b3276592b29e4b97", null ],
     [ "ER_Search", "namespace_data_provider.html#a3f52cf1fcd1d3584090fd8d8f3694573", null ],
     [ "ExpressionTypeCodeMap", "namespace_data_provider.html#aea7722e98943e0affb132e2e4b082797", null ],
     [ "ExpressionTypeDescMap", "namespace_data_provider.html#a882d4436b705cb163e50475d8425bb92", null ],
@@ -148,7 +152,6 @@ var namespace_data_provider =
     [ "RoleDescMap", "namespace_data_provider.html#ad9a0d0302a10f1e56f73069a826ac218", null ],
     [ "SignatureTypeCodeMap", "namespace_data_provider.html#a4f94d2d029713d9e3cefe126a2452c7c", null ],
     [ "SignatureTypeDescMap", "namespace_data_provider.html#a4ecf82161a3fd015ddc1a1ec781eeedd", null ],
-    [ "size", "namespace_data_provider.html#af9e4698f9e0ff3d6ed8bf99908e4050c", null ],
     [ "ST_Any", "namespace_data_provider.html#ac6b11fea94f8c37a2aecb292591e8351", null ],
     [ "ST_Field", "namespace_data_provider.html#aa19c0ad5db7458b33df45f2e3f428b78", null ],
     [ "ST_Value", "namespace_data_provider.html#a17f61e6fae0c6df2df438b874537bdae", null ],
