@@ -1,5 +1,6 @@
 var NAVTREEINDEX6 =
 {
+"group__object__functions.html#ga3f3c875b6632a9b028a5d63be30bec14":[1,44,1],
 "group__object__functions.html#ga46a72b2a2a84282c5125b6fd7a2e6b23":[1,44,4],
 "group__object__functions.html#ga6a929dc065cfb0b20639ac815be9cad3":[1,44,10],
 "group__object__functions.html#ga6eaee4a61dd7e3f58de1dab76154397f":[1,44,11],
@@ -248,6 +249,5 @@ var NAVTREEINDEX6 =
 "group__string__functions.html#ga2230070c2f14ca70e63cf463f5d688c3":[1,57,62],
 "group__string__functions.html#ga2470edb3a13437c060ec85e7653e022a":[1,57,31],
 "group__string__functions.html#ga25264bfb9950ac66862db9b4a32eeee8":[1,57,60],
-"group__string__functions.html#ga3204bee77dc83e5095f95f6582e591c0":[1,57,84],
-"group__string__functions.html#ga32070517a9f8a70a32ef48f83a6f128e":[1,57,47]
+"group__string__functions.html#ga3204bee77dc83e5095f95f6582e591c0":[1,57,84]
 };
