@@ -1,5 +1,6 @@
 var NAVTREEINDEX7 =
 {
+"group__string__functions.html#ga32070517a9f8a70a32ef48f83a6f128e":[1,57,47],
 "group__string__functions.html#ga33bb08516773ed10def16bb42d6b8159":[1,57,24],
 "group__string__functions.html#ga343548c069d7b8d02c522acd05179bf1":[1,57,6],
 "group__string__functions.html#ga3461a37dbd3d51bc03e58b85daae2466":[1,57,50],
@@ -248,6 +249,5 @@ var NAVTREEINDEX7 =
 "group__type__conversion__functions.html#ga181e32c9bc8075431e88bb9bb56285a9":[1,68,23],
 "group__type__conversion__functions.html#ga1dc01cd648400e3bf4b2e69703b861b0":[1,68,3],
 "group__type__conversion__functions.html#ga1f8120b971c551f639a3f8f3c22840d2":[1,68,8],
-"group__type__conversion__functions.html#ga22c89291d4105fcb558f49fe49aeae44":[1,68,7],
-"group__type__conversion__functions.html#ga2cea7c8bd0f40661965bf9e5a35b0a81":[1,68,4]
+"group__type__conversion__functions.html#ga22c89291d4105fcb558f49fe49aeae44":[1,68,7]
 };
