@@ -1,5 +1,6 @@
 var NAVTREEINDEX8 =
 {
+"group__type__conversion__functions.html#ga2cea7c8bd0f40661965bf9e5a35b0a81":[1,68,4],
 "group__type__conversion__functions.html#ga2de8717e92c5f97ccc6511f6062d6502":[1,68,17],
 "group__type__conversion__functions.html#ga43bd1e4a512f68f1b9fd3087b591d6d0":[1,68,19],
 "group__type__conversion__functions.html#ga4b52a1cbee7a3aed46c32cb0a938629c":[1,68,18],
@@ -248,6 +249,5 @@ var NAVTREEINDEX8 =
 "struct_data_provider_1_1_data_provider_info.html#abecd5865cd94dbaed26069cc83a5fc09":[3,0,0,15,34],
 "struct_data_provider_1_1_data_provider_info.html#abfca9615ebec881841d9ee1127d041dc":[3,0,0,15,18],
 "struct_data_provider_1_1_data_provider_info.html#ac07c145f3daaa8e7405b3710d9419df5":[3,0,0,15,6],
-"struct_data_provider_1_1_data_provider_info.html#ac2d3daf465ad7b27a78ffd57072ebb82":[3,0,0,15,23],
-"struct_data_provider_1_1_data_provider_info.html#ace544d5dd078f6284495b6ffc10e4a32":[3,0,0,15,37]
+"struct_data_provider_1_1_data_provider_info.html#ac2d3daf465ad7b27a78ffd57072ebb82":[3,0,0,15,23]
 };
