@@ -8,12 +8,14 @@ var struct_data_provider_1_1_data_provider_info =
     [ "create_options", "struct_data_provider_1_1_data_provider_info.html#a9e6e33aeb3955e61397c79287a6a7a5d", null ],
     [ "delete_field_options", "struct_data_provider_1_1_data_provider_info.html#ac07c145f3daaa8e7405b3710d9419df5", null ],
     [ "desc", "struct_data_provider_1_1_data_provider_info.html#adc3381f78eea899e4c7c9983fa654922", null ],
+    [ "expressions", "struct_data_provider_1_1_data_provider_info.html#a1b627116aab7c4527f4f3e59e14a8c5d", null ],
     [ "has_record", "struct_data_provider_1_1_data_provider_info.html#afb1c6af92a1a848733b5dcae214986c6", null ],
     [ "mapper_keys", "struct_data_provider_1_1_data_provider_info.html#a78d08fa3c961f677293318f2f482c1d7", null ],
     [ "name", "struct_data_provider_1_1_data_provider_info.html#a59faa103679df01e9e501de63472d39e", null ],
     [ "record_requires_search_options", "struct_data_provider_1_1_data_provider_info.html#a8664b380bead15fdb3582b8f7e0767dc", null ],
     [ "request_options", "struct_data_provider_1_1_data_provider_info.html#a4ef503043dde9ad5921fb1d31dc84f8d", null ],
     [ "schema_type", "struct_data_provider_1_1_data_provider_info.html#af63cb50938a573bf4f4a4532ba3a9354", null ],
+    [ "search_logic_capabilities", "struct_data_provider_1_1_data_provider_info.html#af3510c9097c8b51f3741eef08e0b1e5e", null ],
     [ "search_options", "struct_data_provider_1_1_data_provider_info.html#a558497c0cbd189290573fc58142ec544", null ],
     [ "supports_add_field", "struct_data_provider_1_1_data_provider_info.html#a5d8320604f5f3de063c25ea673c6ccf4", null ],
     [ "supports_bulk_create", "struct_data_provider_1_1_data_provider_info.html#abfca9615ebec881841d9ee1127d041dc", null ],
@@ -29,6 +31,7 @@ var struct_data_provider_1_1_data_provider_info =
     [ "supports_read", "struct_data_provider_1_1_data_provider_info.html#a82f69a9926a237125d3c12482647c404", null ],
     [ "supports_request", "struct_data_provider_1_1_data_provider_info.html#a92c8bec23b5baecd32d0a27c640859e1", null ],
     [ "supports_schema", "struct_data_provider_1_1_data_provider_info.html#ae9a9bd29af4c27233fccaa9fc7d4b924", null ],
+    [ "supports_search_expressions", "struct_data_provider_1_1_data_provider_info.html#a8d873e9d25f7ed6e0dfb1d956a0557c8", null ],
     [ "supports_update", "struct_data_provider_1_1_data_provider_info.html#a8add15abae4ec692dea441ffafe189f7", null ],
     [ "supports_update_field", "struct_data_provider_1_1_data_provider_info.html#a9226d33657b357f745887d1eac834aed", null ],
     [ "supports_upsert", "struct_data_provider_1_1_data_provider_info.html#abecd5865cd94dbaed26069cc83a5fc09", null ],
