@@ -3,13 +3,14 @@ var class_freetds_sql_util_1_1_freetds_table =
     [ "clearImpl", "class_freetds_sql_util_1_1_freetds_table.html#a85c29b2cce8d127e56e0ed8db788063c", null ],
     [ "constraintsLinkedToIndexesImpl", "class_freetds_sql_util_1_1_freetds_table.html#a60899956e8e4fcfbc17c61bbe5c4e13e", null ],
     [ "copyImpl", "class_freetds_sql_util_1_1_freetds_table.html#a940d027d852eb0f92c1aacffb8f71cc2", null ],
-    [ "doSelectLimitOnlyUnlockedImpl", "class_freetds_sql_util_1_1_freetds_table.html#a463792dae806907759dd5171b741fdaf", null ],
-    [ "doSelectOrderByWithOffsetSqlUnlockedImpl", "class_freetds_sql_util_1_1_freetds_table.html#abe7addf5da0e8ffd8483dafb4b92a724", null ],
+    [ "doSelectLimitOnlyUnlockedImpl", "class_freetds_sql_util_1_1_freetds_table.html#af36b5a05dee72845217de37f4a6d754f", null ],
+    [ "doSelectOrderByWithOffsetSqlUnlockedImpl", "class_freetds_sql_util_1_1_freetds_table.html#a167ff5f9064496b578a3dff4640346ef", null ],
     [ "getColumnOperatorMapImpl", "class_freetds_sql_util_1_1_freetds_table.html#a3913199fe13c7f94683118cfe55f7cd1", null ],
     [ "getColumnSqlName", "class_freetds_sql_util_1_1_freetds_table.html#a8ee25f1698e230e4cc4390912f2c8d17", null ],
     [ "getColumnSqlNames", "class_freetds_sql_util_1_1_freetds_table.html#a09f16962c586afa32bc14e22d4e9ed56", null ],
     [ "getCreateSqlImpl", "class_freetds_sql_util_1_1_freetds_table.html#adf8635bc5f4011c5cd4fe5ecb8040207", null ],
     [ "getCreateTableSqlImpl", "class_freetds_sql_util_1_1_freetds_table.html#a950f1f0d329288a2c058eae1cb20d517", null ],
+    [ "getExpressionMap", "class_freetds_sql_util_1_1_freetds_table.html#a6c6a423af8a49815a730847a4f661ea8", null ],
     [ "getInsertOperatorMap", "class_freetds_sql_util_1_1_freetds_table.html#a37983f23fa389da19fff042cc890d9c4", null ],
     [ "getNumericTypeImpl", "class_freetds_sql_util_1_1_freetds_table.html#a62c108762d2a2873b02d34db00058826", null ],
     [ "getRawUpdateOperatorMap", "class_freetds_sql_util_1_1_freetds_table.html#af393f2ddb3955ec6f372dc5f25f751d9", null ],
@@ -30,6 +31,7 @@ var class_freetds_sql_util_1_1_freetds_table =
     [ "default_schema", "class_freetds_sql_util_1_1_freetds_table.html#aec2195ee663d15de8a603243d6b9da09", null ],
     [ "filegroup", "class_freetds_sql_util_1_1_freetds_table.html#a5d1646df0a73b2c6146e50a7f498b4d3", null ],
     [ "FreetdsCopMap", "class_freetds_sql_util_1_1_freetds_table.html#a4f9e7da36f2a5054e0936c11838f8e91", null ],
+    [ "FreetdsExpressionMap", "class_freetds_sql_util_1_1_freetds_table.html#a74561b956b74671430e30b27850b84c8", null ],
     [ "FreetdsIopMap", "class_freetds_sql_util_1_1_freetds_table.html#a14fe75d83e06f155ceedcbe9cd7a003e", null ],
     [ "FreetdsOpMap", "class_freetds_sql_util_1_1_freetds_table.html#ab7964c820d1d5a75b167d882c503d255", null ],
     [ "FreetdsSelectOptions", "class_freetds_sql_util_1_1_freetds_table.html#a6ac92ebc74deae2b9bb8177c8bf44c3a", null ],
