@@ -1,5 +1,6 @@
 var NAVTREEINDEX3 =
 {
+"group__math__functions.html#gadd0761e8ac44a20734c5f9e22f972535":[1,33,23],
 "group__math__functions.html#gaddd772711a98adc77dab2d3fe44caa0e":[1,33,38],
 "group__math__functions.html#gade650051a32f10bd32c11e43147f5c9f":[1,33,32],
 "group__math__functions.html#gae19f38dfe1db9a2301e416a3856407c5":[1,33,30],
@@ -248,6 +249,5 @@ var NAVTREEINDEX3 =
 "group__parse__options.html#ga36ecb26e0659608fc8d35bf9c9a3b5b2":[1,45,33],
 "group__parse__options.html#ga3a99f2973e97f3986630d8204d7b91fd":[1,45,68],
 "group__parse__options.html#ga3c3e756af62387846808a0a2f19ca810":[1,45,47],
-"group__parse__options.html#ga454fabf3a392b8fec9ee587e97a2d8e8":[1,45,58],
-"group__parse__options.html#ga46fa5284de5681ab4c8e8cb842f35fff":[1,45,21]
+"group__parse__options.html#ga454fabf3a392b8fec9ee587e97a2d8e8":[1,45,58]
 };
